@@ -1,23 +1,21 @@
 # encoding: utf-8
 
 module Nanoc
-
   # @return [String] A string containing information about this nanoc version
   #   and its environment (Ruby engine and version, Rubygems version if any).
   def self.version_information
     gem_info = defined?(Gem) ? "with RubyGems #{Gem::VERSION}" : 'without RubyGems'
     engine   = defined?(RUBY_ENGINE) ? RUBY_ENGINE : 'ruby'
     res = ''
-    res << "nanoc #{Nanoc::VERSION} © 2007-2014 Denis Defreyne.\n"
+    res << "nanoc #{Nanoc::VERSION} © 2007-2015 Denis Defreyne.\n"
     res << "Running #{engine} #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) on #{RUBY_PLATFORM} #{gem_info}.\n"
     res
   end
 
   # @return [Boolean] True if the current platform is Windows,
   def self.on_windows?
-    !!(RUBY_PLATFORM =~ /windows|bccwin|cygwin|djgpp|mingw|mswin|wince/i)
+    RUBY_PLATFORM =~ /windows|bccwin|cygwin|djgpp|mingw|mswin|wince/i
   end
-
 end
 
 Nanoc3 = Nanoc
