@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc
-
   # Nanoc::CodeSnippet represent a piece of custom code of a nanoc site.
   class CodeSnippet
-
     # A string containing the actual code in this code snippet.
     #
     # @return [String]
@@ -22,9 +20,9 @@ module Nanoc
     #
     # @param [String] filename The filename corresponding to this code snippet
     #
-    # @param [Time, Hash] params Extra parameters. Ignored by nanoc; it is
+    # @param [Time, Hash] _params Extra parameters. Ignored by nanoc; it is
     #   only included for backwards compatibility.
-    def initialize(data, filename, params = nil)
+    def initialize(data, filename, _params = nil)
       @data     = data
       @filename = filename
     end
@@ -40,7 +38,7 @@ module Nanoc
     #
     # @return [Object] An unique reference to this object
     def reference
-      [ :code_snippet, filename ]
+      [:code_snippet, filename]
     end
 
     def inspect
@@ -52,7 +50,5 @@ module Nanoc
     def checksum
       Nanoc::Checksummer.calc(self)
     end
-
   end
-
 end
