@@ -16,7 +16,6 @@ if Nanoc.on_windows?
 end
 
 module Nanoc::CLI
-
   module Commands
   end
 
@@ -28,7 +27,7 @@ module Nanoc::CLI
   autoload 'ErrorHandler',        'nanoc/cli/error_handler'
 
   # Deprecated; use CommandRunner instead
-  # TODO [in nanoc 4.0] remove me
+  # TODO: [in nanoc 4.0] remove me
   autoload 'Command',             'nanoc/cli/command_runner'
 
   # @return [Boolean] true if debug output is enabled, false if not
@@ -48,9 +47,9 @@ module Nanoc::CLI
     @debug = boolean
   end
 
-  # Invokes the nanoc commandline tool with the given arguments.
+  # Invokes the nanoc command-line tool with the given arguments.
   #
-  # @param [Array<String>] args An array of commandline arguments
+  # @param [Array<String>] args An array of command-line arguments
   #
   # @return [void]
   def self.run(args)
@@ -60,7 +59,7 @@ module Nanoc::CLI
     end
   end
 
-  # @return [Cri::Command] The root command, i.e. the commandline tool itself
+  # @return [Cri::Command] The root command, i.e. the command-line tool itself
   def self.root_command
     @root_command
   end
@@ -78,20 +77,20 @@ module Nanoc::CLI
   #
   # @return [void]
   def self.after_setup(&block)
-    # TODO decide what should happen if the CLI is already set up
-    self.add_after_setup_proc(block)
+    # TODO: decide what should happen if the CLI is already set up
+    add_after_setup_proc(block)
   end
 
-protected
+  protected
 
-  # Makes the commandline interface ready for use.
+  # Makes the command-line interface ready for use.
   #
   # @return [void]
   def self.setup
     setup_cleaning_streams
     setup_commands
     load_custom_commands
-    after_setup_procs.each { |b| b.call }
+    after_setup_procs.each(&:call)
   end
 
   # Sets up the root command and base subcommands.
@@ -118,16 +117,25 @@ protected
     end
   end
 
-  # Loads site-specific commands in `commands/`.
+  # Loads site-specific commands.
   #
   # @return [void]
   def self.load_custom_commands
-    recursive_contents_of('commands').each do |filename|
+    if Nanoc::Site.cwd_is_nanoc_site?
+      site = Nanoc::Site.new('.')
+      site.config[:commands_dirs].each do |path|
+        load_commands_at(path)
+      end
+    end
+  end
+
+  def self.load_commands_at(path)
+    recursive_contents_of(path).each do |filename|
       # Create command
       command = Nanoc::CLI.load_command_at(filename)
 
       # Get supercommand
-      pieces = filename.gsub(/^commands\/|\.rb$/, '').split('/')
+      pieces = filename.gsub(/^#{path}\/|\.rb$/, '').split('/')
       pieces = pieces[0, pieces.size - 1] || []
       root = Nanoc::CLI.root_command
       supercommand = pieces.reduce(root) do |cmd, piece|
@@ -177,11 +185,11 @@ protected
   def self.wrap_in_cleaning_stream(io)
     cio = ::Nanoc::CLI::CleaningStream.new(io)
 
-    if !self.enable_utf8?(io)
+    unless self.enable_utf8?(io)
       cio.add_stream_cleaner(Nanoc::CLI::StreamCleaners::UTF8)
     end
 
-    if !self.enable_ansi_colors?(io)
+    unless self.enable_ansi_colors?(io)
       cio.add_stream_cleaner(Nanoc::CLI::StreamCleaners::ANSIColors)
     end
 
@@ -198,14 +206,14 @@ protected
 
   # @return [Boolean] true if UTF-8 support is present, false if not
   def self.enable_utf8?(io)
-    return true if !io.tty?
+    return true unless io.tty?
 
     %w( LC_ALL LC_CTYPE LANG ).any? { |e| ENV[e] =~ /UTF/i }
   end
 
   # @return [Boolean] true if color support is present, false if not
   def self.enable_ansi_colors?(io)
-    if !io.tty?
+    unless io.tty?
       return false
     end
 
@@ -224,5 +232,4 @@ protected
     @after_setup_procs ||= []
     @after_setup_procs << proc
   end
-
 end
