@@ -1,8 +1,8 @@
 # encoding: utf-8
 
-usage       'create-item [options] identifier'
-aliases     :create_item, :ci
-summary     'create an item'
+usage 'create-item [options] identifier'
+aliases :create_item, :ci
+summary 'create an item'
 description <<-EOS
 Create a new item in the current site. The first data source in the site
 configuration will be used.
@@ -11,9 +11,7 @@ EOS
 required :c, :vcs, 'specify the VCS to use'
 
 module Nanoc::CLI::Commands
-
   class CreateItem < ::Nanoc::CLI::CommandRunner
-
     def run
       # Check arguments
       if arguments.length != 1
@@ -30,9 +28,9 @@ module Nanoc::CLI::Commands
       set_vcs(options[:vcs])
 
       # Check whether item is unique
-      if !site.items.find { |i| i.identifier == identifier }.nil?
+      unless site.items.find { |i| i.identifier == identifier }.nil?
         raise Nanoc::Errors::GenericTrivial,
-          "An item already exists at #{identifier}. Please " +
+          "An item already exists at #{identifier}. Please " \
           'pick a unique name for the item you are creating.'
       end
 
@@ -45,15 +43,13 @@ module Nanoc::CLI::Commands
       data_source = site.data_sources[0]
       data_source.create_item(
         "Hi, I'm a new item!\n",
-        { :title => 'A New Item' },
+        { title: 'A New Item' },
         identifier
       )
 
       puts "An item has been created at #{identifier}."
     end
-
   end
-
 end
 
 runner Nanoc::CLI::Commands::CreateItem
