@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::DataSources
-
   # @deprecated Fetch data from online data sources manually instead
   class Delicious < Nanoc::DataSource
-
     def items
       @items ||= begin
         require 'json'
@@ -21,12 +19,12 @@ module Nanoc::DataSources
           # Get data
           content = raw_item['n']
           attributes = {
-            :url         => raw_item['u'],
-            :description => raw_item['d'],
-            :tags        => raw_item['t'],
-            :date        => Time.parse(raw_item['dt']),
-            :note        => raw_item['n'],
-            :author      => raw_item['a']
+            url: raw_item['u'],
+            description: raw_item['d'],
+            tags: raw_item['t'],
+            date: Time.parse(raw_item['dt']),
+            note: raw_item['n'],
+            author: raw_item['a']
           }
           identifier = "/#{i}/"
           mtime = nil
@@ -36,7 +34,5 @@ module Nanoc::DataSources
         end
       end
     end
-
   end
-
 end
