@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::DataSources
-
   # @deprecated Fetch data from online data sources manually instead
   class Twitter < Nanoc::DataSource
-
     def items
       @item ||= begin
         require 'json'
@@ -17,12 +15,12 @@ module Nanoc::DataSources
         raw_items = JSON.parse(data)
 
         # Convert to items
-        raw_items.enum_with_index.map do |raw_item, i|
+        raw_items.enum_with_index.map do |raw_item, _i|
           # Get data
           content = raw_item['text']
           attributes = {
-            :created_at  => raw_item['created_at'],
-            :source      => raw_item['source']
+            created_at: raw_item['created_at'],
+            source: raw_item['source']
           }
           identifier = "/#{raw_item['id']}/"
           mtime = Time.parse(raw_item['created_at'])
@@ -32,7 +30,5 @@ module Nanoc::DataSources
         end
       end
     end
-
   end
-
 end
