@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::DataSources
-
   # Provides functionality common across all filesystem data sources.
   module Filesystem
-
     # The VCS that will be called when adding, deleting and moving files. If
     # no VCS has been set, or if the VCS has been set to `nil`, a dummy VCS
     # will be returned.
@@ -34,7 +32,7 @@ module Nanoc::DataSources
     # See {Nanoc::DataSource#setup}.
     def setup
       # Create directories
-      [ content_dir_name, layouts_dir_name ].each do |dir|
+      [content_dir_name, layouts_dir_name].each do |dir|
         FileUtils.mkdir_p(dir)
         vcs.add(dir)
       end
@@ -60,12 +58,12 @@ module Nanoc::DataSources
       create_object(layouts_dir_name, content, attributes, identifier, params)
     end
 
-  protected
+    protected
 
     # Creates a new object (item or layout) on disk in dir_name according to
     # the given identifier. The file will have its attributes taken from the
     # attributes hash argument and its content from the content argument.
-    def create_object(dir_name, content, attributes, identifier, params = {})
+    def create_object(_dir_name, _content, _attributes, _identifier, _params = {})
       raise NotImplementedError.new(
         "#{self.class} does not implement ##{name}"
       )
@@ -89,7 +87,7 @@ module Nanoc::DataSources
         content_filename = filename_for(base_filename, content_ext)
 
         # Read content and metadata
-        is_binary = !!(content_filename && !@site.config[:text_extensions].include?(File.extname(content_filename)[1..-1]))
+        is_binary = content_filename && !@site.config[:text_extensions].include?(File.extname(content_filename)[1..-1])
         if is_binary && klass == Nanoc::Item
           meta                = (meta_filename && YAML.load_file(meta_filename)) || {}
           content_or_filename = content_filename
@@ -101,14 +99,14 @@ module Nanoc::DataSources
 
         # Get attributes
         attributes = {
-          :filename         => content_filename,
-          :content_filename => content_filename,
-          :meta_filename    => meta_filename,
-          :extension        => content_filename ? ext_of(content_filename)[1..-1] : nil,
+          filename: content_filename,
+          content_filename: content_filename,
+          meta_filename: meta_filename,
+          extension: content_filename ? ext_of(content_filename)[1..-1] : nil,
           # WARNING :file is deprecated; please create a File object manually
           # using the :content_filename or :meta_filename attributes.
-          # TODO [in nanoc 4.0] remove me
-          :file             => content_filename ? Nanoc::Extra::FileProxy.new(content_filename) : nil
+          # TODO: [in nanoc 4.0] remove me
+          file: content_filename ? Nanoc::Extra::FileProxy.new(content_filename) : nil
         }.merge(meta)
 
         # Get identifier
@@ -121,7 +119,7 @@ module Nanoc::DataSources
         end
 
         # Get modification times
-        meta_mtime    = meta_filename    ? File.stat(meta_filename).mtime    : nil
+        meta_mtime = meta_filename ? File.stat(meta_filename).mtime : nil
         content_mtime = content_filename ? File.stat(content_filename).mtime : nil
         if meta_mtime && content_mtime
           mtime = meta_mtime > content_mtime ? meta_mtime : content_mtime
@@ -136,7 +134,7 @@ module Nanoc::DataSources
         # Create layout object
         klass.new(
           content_or_filename, attributes, identifier,
-          :binary => is_binary, :mtime => mtime
+          binary: is_binary, mtime: mtime
         )
       end
     end
@@ -153,9 +151,10 @@ module Nanoc::DataSources
     #     'content/qux' => [ nil,    'html' ]
     #   }
     def all_split_files_in(dir_name)
-      grouped_filenames = all_files_in(dir_name).
-        reject   { |fn| fn =~ /(~|\.orig|\.rej|\.bak)$/ }.
-        group_by { |fn| basename_of(fn) }
+      grouped_filenames =
+        all_files_in(dir_name)
+        .reject   { |fn| fn =~ /(~|\.orig|\.rej|\.bak)$/ }
+        .group_by { |fn| basename_of(fn) }
 
       grouped_filenames.each_pair do |key, filenames|
         # Divide
@@ -163,15 +162,15 @@ module Nanoc::DataSources
         content_filenames = filenames.select { |fn| ext_of(fn) != '.yaml' }
 
         # Check number of files per type
-        if ![ 0, 1 ].include?(meta_filenames.size)
+        unless [0, 1].include?(meta_filenames.size)
           raise "Found #{meta_filenames.size} meta files for #{key}; expected 0 or 1"
         end
-        if ![ 0, 1 ].include?(content_filenames.size)
+        unless [0, 1].include?(content_filenames.size)
           raise "Found #{content_filenames.size} content files for #{key}; expected 0 or 1"
         end
 
         # Reorder elements and convert to extnames
-        filenames[0] = meta_filenames[0]    ? 'yaml'                                   : nil
+        filenames[0] = meta_filenames[0] ? 'yaml' : nil
         filenames[1] = content_filenames[0] ? ext_of(content_filenames[0])[1..-1] || '' : nil
       end
 
@@ -180,7 +179,7 @@ module Nanoc::DataSources
 
     # Returns all files in the given directory and directories below it.
     def all_files_in(dir_name)
-      Nanoc::Extra::FilesystemTools.all_files_in(dir_name)
+      Nanoc::Extra::FilesystemTools.all_files_in(dir_name, config[:extra_files])
     end
 
     # Returns the filename for the given base filename and the extension.
@@ -193,7 +192,7 @@ module Nanoc::DataSources
     # data sources may prefer to implement this differently (for example,
     # {Nanoc::DataSources::FilesystemVerbose} doubles the last part of the
     # basename before concatenating it with a period and the extension).
-    def filename_for(base_filename, ext)
+    def filename_for(_base_filename, _ext)
       raise NotImplementedError.new(
         "#{self.class} does not implement #filename_for"
       )
@@ -201,7 +200,7 @@ module Nanoc::DataSources
 
     # Returns the identifier that corresponds with the given filename, which
     # can be the content filename or the meta filename.
-    def identifier_for_filename(filename)
+    def identifier_for_filename(_filename)
       raise NotImplementedError.new(
         "#{self.class} does not implement #identifier_for_filename"
       )
@@ -235,7 +234,7 @@ module Nanoc::DataSources
     # Parses the file named `filename` and returns an array with its first
     # element a hash with the file's metadata, and with its second element the
     # file content itself.
-    def parse(content_filename, meta_filename, kind)
+    def parse(content_filename, meta_filename, _kind)
       # Read content and metadata from separate files
       if meta_filename
         content = content_filename ? read(content_filename) : ''
@@ -245,7 +244,7 @@ module Nanoc::DataSources
         rescue Exception => e
           raise "Could not parse YAML for #{meta_filename}: #{e.message}"
         end
-        return [ meta, content ]
+        return [meta, content]
       end
 
       # Read data
@@ -253,7 +252,7 @@ module Nanoc::DataSources
 
       # Check presence of metadata section
       if data !~ /\A-{3,5}\s*$/
-        return [ {}, data ]
+        return [{}, data]
       end
 
       # Split data
@@ -273,7 +272,7 @@ module Nanoc::DataSources
       content = pieces[4]
 
       # Done
-      [ meta, content ]
+      [meta, content]
     end
 
     # Reads the content of the file with the given name and returns a string
@@ -303,7 +302,7 @@ module Nanoc::DataSources
           raise_encoding_error(filename, original_encoding)
         end
 
-        if !data.valid_encoding?
+        unless data.valid_encoding?
           raise_encoding_error(filename, original_encoding)
         end
       end
@@ -318,7 +317,5 @@ module Nanoc::DataSources
     def raise_encoding_error(filename, encoding)
       raise RuntimeError.new("Could not read #{filename} because the file is not valid #{encoding}.")
     end
-
   end
-
 end
