@@ -1,11 +1,9 @@
 # encoding: utf-8
 
 module Nanoc::Extra
-
   # A web server that will automatically compile items as they are requested.
   # It also serves static files such as stylesheets and images.
   class AutoCompiler
-
     # @return [Nanoc::Site] The site this autocompiler belongs to
     attr_reader :site
 
@@ -38,10 +36,10 @@ module Nanoc::Extra
 
         # Find rep
         path = Rack::Utils.unescape(env['PATH_INFO'])
-        reps = site.items.map { |i| i.reps }.flatten
+        reps = site.items.map(&:reps).flatten
         rep = reps.find do |r|
           r.path == path ||
-            r.raw_path == site.config[:output_dir] + path
+          r.raw_path == site.config[:output_dir] + path
         end
 
         # Recompile
@@ -51,7 +49,7 @@ module Nanoc::Extra
         if path =~ /\/$/
           possible_paths = site.config[:index_filenames].map { |f| path + f }
         else
-          possible_paths = [ path ]
+          possible_paths = [path]
         end
 
         # Find matching file
@@ -67,7 +65,7 @@ module Nanoc::Extra
     rescue StandardError, ScriptError => e
       # Add compilation stack to env
       env['nanoc.stack'] = []
-      stack.reverse.each do |obj|
+      stack.reverse_each do |obj|
         if obj.is_a?(Nanoc::ItemRep) # item rep
           env['nanoc.stack'] << "[item] #{obj.item.identifier} (rep #{obj.name})"
         else # layout
@@ -79,7 +77,7 @@ module Nanoc::Extra
       raise e
     end
 
-  private
+    private
 
     def build_site
       @site = Nanoc::Site.new(@site_path)
@@ -97,7 +95,5 @@ module Nanoc::Extra
     def stack
       site.compiler.stack
     end
-
   end
-
 end
