@@ -5,24 +5,21 @@ require 'rack'
 require 'rack/cache'
 
 module Nanoc::Extra
-
   # @deprecated Use a HTTP library such as
   #   [Net::HTTP](http://ruby-doc.org/stdlib/libdoc/net/http/rdoc/) or
   #   [Curb](https://github.com/taf2/curb) instead.
   module CHiCk
-
     # @deprecated Use a HTTP library such as
     #   [Net::HTTP](http://ruby-doc.org/stdlib/libdoc/net/http/rdoc/) or
     #   [Curb](https://github.com/taf2/curb) instead.
     class Client
-
       DEFAULT_OPTIONS = {
-        :cache => {
-          :metastore   => 'file:tmp/rack/cache.meta',
-          :entitystore => 'file:tmp/rack/cache.body'
+        cache: {
+          metastore: 'file:tmp/rack/cache.meta',
+          entitystore: 'file:tmp/rack/cache.body'
         },
-        :cache_controller => {
-          :max_age => 60
+        cache_controller: {
+          max_age: 60
         }
       }
 
@@ -37,13 +34,13 @@ module Nanoc::Extra
         # Build app
         options = @options
         @app ||= Rack::Builder.new do
-          use Rack::Cache, options[:cache].merge(:verbose => true)
+          use Rack::Cache, options[:cache].merge(verbose: true)
           use Nanoc::Extra::CHiCk::CacheController, options[:cache_controller]
           run Nanoc::Extra::CHiCk::RackClient
         end
 
         # Build environment for request
-        env = Rack::MockRequest.env_for(url, :method => 'GET')
+        env = Rack::MockRequest.env_for(url, method: 'GET')
 
         # Fetch
         puts "[CHiCk] Fetching #{url}..." if $DEBUG
@@ -55,16 +52,14 @@ module Nanoc::Extra
         body_parts.each { |part| body << part }
 
         # Done
-        [ status, headers, body ]
+        [status, headers, body]
       end
-
     end
 
     # @deprecated Use a HTTP library such as
     #   [Net::HTTP](http://ruby-doc.org/stdlib/libdoc/net/http/rdoc/) or
     #   [Curb](https://github.com/taf2/curb) instead.
     class CacheController
-
       def initialize(app, options = {})
         @app = app
         @options = options
@@ -77,14 +72,12 @@ module Nanoc::Extra
         end
         res
       end
-
     end
 
     # @deprecated Use a HTTP library such as
     #   [Net::HTTP](http://ruby-doc.org/stdlib/libdoc/net/http/rdoc/) or
     #   [Curb](https://github.com/taf2/curb) instead.
     class RackClient
-
       METHOD_TO_CLASS_MAPPING = {
         'DELETE'  => Net::HTTP::Delete,
         'GET'     => Net::HTTP::Get,
@@ -115,13 +108,10 @@ module Nanoc::Extra
           return [
             response.code.to_i,
             response.to_hash.reduce({}) { |m, (k, v)| m.merge(k => v[0]) },
-            [ response.body ]
+            [response.body]
           ]
         end
       end
-
     end
-
   end
-
 end
