@@ -3,9 +3,7 @@
 require 'singleton'
 
 module Nanoc::Extra
-
   class JRubyNokogiriWarner
-
     include Singleton
 
     TEXT = <<EOS
@@ -35,14 +33,12 @@ EOS
     end
 
     def check_and_warn
-      return if !defined?(RUBY_ENGINE)
+      return unless defined?(RUBY_ENGINE)
       return if RUBY_ENGINE != 'jruby'
       return if @warned
 
       $stderr.puts TEXT
       @warned = true
     end
-
   end
-
 end
