@@ -3,11 +3,8 @@
 require 'open3'
 
 module Nanoc::Extra
-
   class Piper
-
     class Error < ::Nanoc::Errors::Generic
-
       def initialize(command, exit_code)
         @command   = command
         @exit_code = exit_code
@@ -16,12 +13,11 @@ module Nanoc::Extra
       def message
         "command exited with a nonzero status code #{@exit_code} (command: #{@command.join(' ')})"
       end
-
     end
 
     # @option [IO] :stdout ($stdout)
     # @option [IO] :stderr ($stderr)
-    def initialize(params={})
+    def initialize(params = {})
       @stdout = params.fetch(:stdout, $stdout)
       @stderr = params.fetch(:stderr, $stderr)
     end
@@ -43,12 +39,10 @@ module Nanoc::Extra
         stderr_thread.join
 
         exit_status = wait_thr.value
-        if !exit_status.success?
+        unless exit_status.success?
           raise Error.new(cmd, exit_status.to_i)
         end
       end
     end
-
   end
-
 end
