@@ -1,12 +1,10 @@
 # encoding: utf-8
 
 module Nanoc::Extra::VCSes
-
   # @see Nanoc::Extra::VCS
   class Dummy < Nanoc::Extra::VCS
-
     # @see Nanoc::Extra::VCS#add
-    def add(filename)
+    def add(_filename)
     end
 
     # @see Nanoc::Extra::VCS#remove
@@ -18,7 +16,5 @@ module Nanoc::Extra::VCSes
     def move(src, dst)
       FileUtils.move(src, dst)
     end
-
   end
-
 end
