@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class BlueCloth < Nanoc::Filter
-
     requires 'bluecloth'
 
     # Runs the content through [BlueCloth](http://deveiate.org/projects/BlueCloth).
@@ -11,9 +10,8 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       ::BlueCloth.new(content).to_html
     end
-
   end
 end
