@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::Filters
-
   # @since 3.3.0
   class CoffeeScript < Nanoc::Filter
-
     requires 'coffee-script'
 
     # Runs the content through [CoffeeScript](http://coffeescript.org/).
@@ -13,10 +11,8 @@ module Nanoc::Filters
     # @param [String] content The CoffeeScript content to turn into JavaScript
     #
     # @return [String] The resulting JavaScript
-    def run(content, params = {})
+    def run(content, _params = {})
       ::CoffeeScript.compile(content)
     end
-
   end
-
 end
