@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class ERB < Nanoc::Filter
-
     requires 'erb'
 
     # Runs the content through [ERB](http://ruby-doc.org/stdlib/libdoc/erb/rdoc/classes/ERB.html).
@@ -23,7 +22,7 @@ module Nanoc::Filters
       context = ::Nanoc::Context.new(assigns)
 
       # Get binding
-      proc = assigns[:content] ? lambda { assigns[:content] } : nil
+      proc = assigns[:content] ? -> { assigns[:content] } : nil
       assigns_binding = context.get_binding(&proc)
 
       # Get result
@@ -33,6 +32,5 @@ module Nanoc::Filters
       erb.filename = filename
       erb.result(assigns_binding)
     end
-
   end
 end
