@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class Erubis < Nanoc::Filter
-
     requires 'erubis'
 
     # The same as `::Erubis::Eruby` but adds `_erbout` as an alias for the
@@ -18,17 +17,16 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       # Create context
       context = ::Nanoc::Context.new(assigns)
 
       # Get binding
-      proc = assigns[:content] ? lambda { assigns[:content] } : nil
+      proc = assigns[:content] ? -> { assigns[:content] } : nil
       assigns_binding = context.get_binding(&proc)
 
       # Get result
-      ErubisWithErbout.new(content, :filename => filename).result(assigns_binding)
+      ErubisWithErbout.new(content, filename: filename).result(assigns_binding)
     end
-
   end
 end
