@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class Haml < Nanoc::Filter
-
     requires 'haml'
 
     # Runs the content through [Haml](http://haml-lang.com/).
@@ -13,15 +12,14 @@ module Nanoc::Filters
     # @return [String] The filtered content
     def run(content, params = {})
       # Get options
-      options = params.merge(:filename => filename)
+      options = params.merge(filename: filename)
 
       # Create context
       context = ::Nanoc::Context.new(assigns)
 
       # Get result
-      proc = assigns[:content] ? lambda { assigns[:content] } : nil
+      proc = assigns[:content] ? -> { assigns[:content] } : nil
       ::Haml::Engine.new(content, options).render(context, assigns, &proc)
     end
-
   end
 end
