@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::Filters
-
   # @since 3.4.0
   class Handlebars < Nanoc::Filter
-
     requires 'handlebars'
 
     # Runs the content through
@@ -15,7 +13,7 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       context = item.attributes.dup
       context[:item]   = assigns[:item].attributes
       context[:config] = assigns[:config]
@@ -28,7 +26,5 @@ module Nanoc::Filters
       template = handlebars.compile(content)
       template.call(context)
     end
-
   end
-
 end
