@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class Kramdown < Nanoc::Filter
-
     requires 'kramdown'
 
     # Runs the content through [Kramdown](http://kramdown.gettalong.org/).
@@ -12,9 +11,13 @@ module Nanoc::Filters
     #
     # @return [String] The filtered content
     def run(content, params = {})
-      # Get result
-      ::Kramdown::Document.new(content, params).to_html
-    end
+      document = ::Kramdown::Document.new(content, params)
 
+      document.warnings.each do |warning|
+        $stderr.puts "kramdown warning: #{warning}"
+      end
+
+      document.to_html
+    end
   end
 end
