@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class Markaby < Nanoc::Filter
-
     requires 'markaby'
 
     # Runs the content through [Markaby](http://markaby.github.io/).
@@ -11,10 +10,9 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       # Get result
       ::Markaby::Builder.new(assigns).instance_eval(content).to_s
     end
-
   end
 end
