@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::Filters
-
   # @since 3.2.0
   class Mustache < Nanoc::Filter
-
     requires 'mustache'
 
     # Runs the content through
@@ -14,11 +12,9 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
-      context = item.attributes.merge({ :yield => assigns[:content] })
+    def run(content, _params = {})
+      context = item.attributes.merge({ yield: assigns[:content] })
       ::Mustache.render(content, context)
     end
-
   end
-
 end
