@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class RDoc < Nanoc::Filter
-
     requires 'rdoc'
 
     def self.setup
@@ -16,11 +15,10 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       options = ::RDoc::Options.new
       to_html = ::RDoc::Markup::ToHtml.new(options)
       ::RDoc::Markup.new.convert(content, to_html)
     end
-
   end
 end
