@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class RubyPants < Nanoc::Filter
-
     requires 'rubypants'
 
     # Runs the content through [RubyPants](http://rubydoc.info/gems/rubypants/).
@@ -11,10 +10,9 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       # Get result
       ::RubyPants.new(content).to_html
     end
-
   end
 end
