@@ -2,7 +2,6 @@
 
 module Nanoc::Filters
   class Sass < Nanoc::Filter
-
     requires 'sass', 'nanoc/filters/sass/sass_filesystem_importer'
 
     # Runs the content through [Sass](http://sass-lang.com/).
@@ -13,8 +12,8 @@ module Nanoc::Filters
     # @return [String] The filtered content
     def run(content, params = {})
       options = params.merge({
-        :nanoc_current_filter => self,
-        :filename => @item && @item.raw_filename,
+        nanoc_current_filter: self,
+        filename: @item && @item.raw_filename,
       })
       engine = ::Sass::Engine.new(content, options)
       engine.render
@@ -26,6 +25,5 @@ module Nanoc::Filters
           Pathname.new(i.raw_filename).realpath == Pathname.new(filename).realpath
       end
     end
-
   end
 end
