@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class ::Sass::Importers::Filesystem
-
   alias_method :_orig_find, :_find
 
   def _find(dir, name, options)
@@ -11,11 +10,12 @@ class ::Sass::Importers::Filesystem
 
     # Create dependency
     filter = options[:nanoc_current_filter]
-    item = filter.imported_filename_to_item(full_filename)
-    filter.depend_on([ item ]) unless item.nil?
+    if filter
+      item = filter.imported_filename_to_item(full_filename)
+      filter.depend_on([item]) unless item.nil?
+    end
 
     # Call original _find
     _orig_find(dir, name, options)
   end
-
 end
