@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::Filters
-
   # @since 3.2.0
   class Slim < Nanoc::Filter
-
     requires 'slim'
 
     # Runs the content through [Slim](http://slim-lang.com/).
@@ -15,8 +13,8 @@ module Nanoc::Filters
     # @return [String] The filtered content
     def run(content, params = {})
       params = {
-        :disable_capture => true,      # Capture managed by nanoc
-        :buffer          => '_erbout', # Force slim to output to the buffer used by nanoc
+        disable_capture: true,      # Capture managed by nanoc
+        buffer: '_erbout', # Force slim to output to the buffer used by nanoc
       }.merge params
 
       # Create context
@@ -24,7 +22,5 @@ module Nanoc::Filters
 
       ::Slim::Template.new(params) { content }.render(context) { assigns[:content] }
     end
-
   end
-
 end
