@@ -1,10 +1,8 @@
 # encoding: utf-8
 
 module Nanoc::Filters
-
   # @since 3.2.0
   class Typogruby < Nanoc::Filter
-
     requires 'typogruby'
 
     # Runs the content through [Typogruby](http://avdgaag.github.com/typogruby/).
@@ -13,11 +11,9 @@ module Nanoc::Filters
     # @param [String] content The content to filter
     #
     # @return [String] The filtered content
-    def run(content, params = {})
+    def run(content, _params = {})
       # Get result
       ::Typogruby.improve(content)
     end
-
   end
-
 end
