@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 module Nanoc::Helpers
-
   # Provides functionality for “capturing” content in one place and reusing
   # this content elsewhere.
   #
@@ -35,10 +34,8 @@ module Nanoc::Helpers
   #     <%= @item[:content_for_summary] || '(no summary)' %>
   #   </div>
   module Capturing
-
     # @api private
     class CapturesStore
-
       def initialize
         @store = {}
       end
@@ -52,11 +49,9 @@ module Nanoc::Helpers
         @store[item.identifier] ||= {}
         @store[item.identifier][name]
       end
-
     end
 
     class ::Nanoc::Site
-
       # @api private
       def captures_store
         @captures_store ||= CapturesStore.new
@@ -67,7 +62,6 @@ module Nanoc::Helpers
         require 'set'
         @captures_store_compiled_items ||= Set.new
       end
-
     end
 
     # @overload content_for(name, &block)
@@ -101,7 +95,7 @@ module Nanoc::Helpers
       if block_given? # Set content
         # Get args
         if args.size != 1
-          raise ArgumentError, 'expected 1 argument (the name ' +
+          raise ArgumentError, 'expected 1 argument (the name ' \
             "of the capture) but got #{args.size} instead"
         end
         name = args[0]
@@ -112,7 +106,7 @@ module Nanoc::Helpers
       else # Get content
         # Get args
         if args.size != 2
-          raise ArgumentError, 'expected 2 arguments (the item ' +
+          raise ArgumentError, 'expected 2 arguments (the item ' \
             "and the name of the capture) but got #{args.size} instead"
         end
         item = args[0]
@@ -127,13 +121,13 @@ module Nanoc::Helpers
           # This is an extremely ugly hack to get the compiler to recompile the
           # item from which we use content. For this, we need to manually edit
           # the content attribute to reset it. :(
-          # FIXME clean this up
-          if !@site.captures_store_compiled_items.include? item
+          # FIXME: clean this up
+          unless @site.captures_store_compiled_items.include? item
             @site.captures_store_compiled_items << item
             item.forced_outdated = true
             item.reps.each do |r|
               raw_content = item.raw_content
-              r.content = { :raw => raw_content, :last => raw_content }
+              r.content = { raw: raw_content, last: raw_content }
               raise Nanoc::Errors::UnmetDependency.new(r)
             end
           end
@@ -169,7 +163,5 @@ module Nanoc::Helpers
       # Done.
       erbout_addition
     end
-
   end
-
 end
