@@ -1,9 +1,7 @@
 # encoding: utf-8
 
 module Nanoc::Tasks
-
   class Clean
-
     def initialize(site)
       @site = site
     end
@@ -14,16 +12,12 @@ module Nanoc::Tasks
       end
     end
 
-  private
+    private
 
     def filenames
       @site.items.map do |item|
-        item.reps.map do |rep|
-          rep.raw_path
-        end
+        item.reps.map(&:raw_path)
       end.flatten
     end
-
   end
-
 end
