@@ -1,13 +1,12 @@
 # encoding: utf-8
 
 describe 'Pathname#checksum' do
-
   it 'should work on empty files' do
     begin
       # Create file
       FileUtils.mkdir_p('tmp')
       File.open('tmp/myfile', 'w') { |io| io.write('') }
-      timestamp = Time.at(1234569)
+      timestamp = Time.at(1_234_569)
       File.utime(timestamp, timestamp, 'tmp/myfile')
 
       # Create checksum
@@ -23,7 +22,7 @@ describe 'Pathname#checksum' do
       # Create file
       FileUtils.mkdir_p('tmp')
       File.open('tmp/myfile', 'w') { |io| io.write('abc') }
-      timestamp = Time.at(1234569)
+      timestamp = Time.at(1_234_569)
       File.utime(timestamp, timestamp, 'tmp/myfile')
 
       # Create checksum
@@ -33,5 +32,4 @@ describe 'Pathname#checksum' do
       FileUtils.rm_rf('tmp')
     end
   end
-
 end
