@@ -1,21 +1,20 @@
 # encoding: utf-8
 
 class Nanoc::ContextTest < Nanoc::TestCase
-
   def test_context_with_instance_variable
     # Create context
-    context = Nanoc::Context.new({ :foo => 'bar', :baz => 'quux' })
+    context = Nanoc::Context.new({ foo: 'bar', baz: 'quux' })
 
     # Ensure correct evaluation
-    assert_equal('bar', eval("@foo", context.get_binding))
+    assert_equal('bar', eval('@foo', context.get_binding))
   end
 
   def test_context_with_instance_method
     # Create context
-    context = Nanoc::Context.new({ :foo => 'bar', :baz => 'quux' })
+    context = Nanoc::Context.new({ foo: 'bar', baz: 'quux' })
 
     # Ensure correct evaluation
-    assert_equal('bar', eval("foo", context.get_binding))
+    assert_equal('bar', eval('foo', context.get_binding))
   end
 
   def test_example
@@ -25,5 +24,4 @@ class Nanoc::ContextTest < Nanoc::TestCase
     # Run
     assert_examples_correct 'Nanoc::Context#initialize'
   end
-
 end
