@@ -1,9 +1,7 @@
 # encoding: utf-8
 
 class Nanoc::MemoizationTest < Nanoc::TestCase
-
   class Sample1
-
     extend Nanoc::Memoization
 
     def initialize(value)
@@ -11,14 +9,12 @@ class Nanoc::MemoizationTest < Nanoc::TestCase
     end
 
     def run(n)
-      @value*10 + n
+      @value * 10 + n
     end
     memoize :run
-
   end
 
   class Sample2
-
     extend Nanoc::Memoization
 
     def initialize(value)
@@ -26,14 +22,12 @@ class Nanoc::MemoizationTest < Nanoc::TestCase
     end
 
     def run(n)
-      @value*100 + n
+      @value * 100 + n
     end
     memoize :run
-
   end
 
   class EqualSample
-
     extend Nanoc::Memoization
 
     def initialize(value)
@@ -44,19 +38,18 @@ class Nanoc::MemoizationTest < Nanoc::TestCase
       4
     end
 
-    def eql?(other)
+    def eql?(_other)
       true
     end
 
-    def ==(other)
+    def ==(_other)
       true
     end
 
     def run(n)
-      @value*10 + n
+      @value * 10 + n
     end
     memoize :run
-
   end
 
   def test
@@ -66,10 +59,10 @@ class Nanoc::MemoizationTest < Nanoc::TestCase
     sample2b = Sample2.new(25)
 
     3.times do
-      assert_equal 10*10+5,  sample1a.run(5)
-      assert_equal 10*15+7,  sample1b.run(7)
-      assert_equal 100*20+5, sample2a.run(5)
-      assert_equal 100*25+7, sample2b.run(7)
+      assert_equal 10 * 10 + 5,  sample1a.run(5)
+      assert_equal 10 * 15 + 7,  sample1b.run(7)
+      assert_equal 100 * 20 + 5, sample2a.run(5)
+      assert_equal 100 * 25 + 7, sample2b.run(7)
     end
   end
 
@@ -78,11 +71,10 @@ class Nanoc::MemoizationTest < Nanoc::TestCase
     sample2 = EqualSample.new(3)
 
     3.times do
-      assert_equal 2*10+5, sample1.run(5)
-      assert_equal 2*10+3, sample1.run(3)
-      assert_equal 3*10+5, sample2.run(5)
-      assert_equal 3*10+3, sample2.run(3)
+      assert_equal 2 * 10 + 5, sample1.run(5)
+      assert_equal 2 * 10 + 3, sample1.run(3)
+      assert_equal 3 * 10 + 5, sample2.run(5)
+      assert_equal 3 * 10 + 3, sample2.run(3)
     end
   end
-
 end
