@@ -1,9 +1,7 @@
 # encoding: utf-8
 
 class Nanoc::StoreTest < Nanoc::TestCase
-
   class TestStore < Nanoc::Store
-
     def data
       @data
     end
@@ -11,7 +9,6 @@ class Nanoc::StoreTest < Nanoc::TestCase
     def data=(new_data)
       @data = new_data
     end
-
   end
 
   def test_delete_and_reload_on_error
@@ -19,13 +16,13 @@ class Nanoc::StoreTest < Nanoc::TestCase
 
     # Create
     store.load
-    store.data = { :fun => 'sure' }
+    store.data = { fun: 'sure' }
     store.store
 
     # Test stored values
     store = TestStore.new('test.db', 1)
     store.load
-    assert_equal({ :fun => 'sure' }, store.data)
+    assert_equal({ fun: 'sure' }, store.data)
 
     # Mess up
     File.open('test.db', 'w') do |io|
@@ -37,5 +34,4 @@ class Nanoc::StoreTest < Nanoc::TestCase
     store.load
     assert_equal(nil, store.data)
   end
-
 end
