@@ -1,9 +1,8 @@
 # encoding: utf-8
 
 class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
-
   def test_profiling_information
-    with_site do |site|
+    with_site do |_site|
       Nanoc::CLI.run %w( create_item foo )
       Nanoc::CLI.run %w( create_item bar )
       Nanoc::CLI.run %w( create_item baz )
@@ -29,7 +28,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   end
 
   def test_auto_prune
-    with_site do |site|
+    with_site do |_site|
       Nanoc::CLI.run %w( create_item foo )
       Nanoc::CLI.run %w( create_item bar )
       Nanoc::CLI.run %w( create_item baz )
@@ -70,7 +69,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   end
 
   def test_auto_prune_with_exclude
-    with_site do |site|
+    with_site do |_site|
       Nanoc::CLI.run %w( create_item foo )
       Nanoc::CLI.run %w( create_item bar )
       Nanoc::CLI.run %w( create_item baz )
@@ -118,18 +117,29 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   def test_setup_and_teardown_listeners
     with_site do
       test_listener_class = Class.new(::Nanoc::CLI::Commands::Compile::Listener) do
-        def start ; @started = true ; end
-        def stop  ; @stopped = true ; end
-        def started? ; @started ; end
-        def stopped? ; @stopped ; end
+        def start
+          @started = true
+        end
+
+        def stop
+          @stopped = true
+        end
+
+        def started?
+          @started
+        end
+
+        def stopped?
+          @stopped
+        end
       end
 
       options = {}
       arguments = []
       cmd = nil
-      listener_classes = [ test_listener_class ]
+      listener_classes = [test_listener_class]
       cmd_runner = Nanoc::CLI::Commands::Compile.new(
-        options, arguments, cmd, :listener_classes => listener_classes)
+        options, arguments, cmd, listener_classes: listener_classes)
 
       cmd_runner.run
 
@@ -148,7 +158,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
     rep.compiled = true
 
     # Listen
-    listener = new_file_action_printer([ rep ])
+    listener = new_file_action_printer([rep])
     listener.start
     Nanoc::NotificationCenter.post(:compilation_started, rep)
     Nanoc::NotificationCenter.post(:rep_written, rep, rep.raw_path, false, true)
@@ -169,7 +179,7 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
     rep.raw_path = 'output/foo.txt'
 
     # Listen
-    listener = new_file_action_printer([ rep ])
+    listener = new_file_action_printer([rep])
     listener.start
     Nanoc::NotificationCenter.post(:compilation_started, rep)
     listener.stop
@@ -183,15 +193,15 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
   end
 
   def new_file_action_printer(reps)
-    listener = Nanoc::CLI::Commands::Compile::FileActionPrinter.new(:reps => reps)
+    listener = Nanoc::CLI::Commands::Compile::FileActionPrinter.new(reps: reps)
 
     def listener.log(level, action, path, duration)
       @events ||= []
       @events << {
-        :level    => level,
-        :action   => action,
-        :path     => path,
-        :duration => duration
+        level: level,
+        action: action,
+        path: path,
+        duration: duration
       }
     end
 
@@ -201,5 +211,4 @@ class Nanoc::CLI::Commands::CompileTest < Nanoc::TestCase
 
     listener
   end
-
 end
