@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
-
   def test_create_site_with_existing_name
     Nanoc::CLI.run %w( create_site foo )
     assert_raises(::Nanoc::Errors::GenericTrivial) do
@@ -19,8 +18,21 @@ class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
     end
   end
 
+  def test_can_compile_new_site_with_binary_items
+    Nanoc::CLI.run %w( create_site foo )
+
+    FileUtils.cd('foo') do
+      File.open('content/blah', 'w') { |io| io << 'asdf' }
+      site = Nanoc::Site.new('.')
+      site.load_data
+      site.compile
+
+      assert File.file?('output/blah')
+    end
+  end
+
   def test_default_encoding
-    if !defined?(Encoding)
+    unless defined?(Encoding)
       skip 'No Encoding class'
       return
     end
@@ -31,14 +43,13 @@ class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
     Nanoc::CLI.run %w( create_site foo )
 
     FileUtils.cd('foo') do
-
       # Try with encoding = default encoding = utf-8
       File.open('content/index.html', 'w') { |io| io.write("Hello <\xD6>!\n") }
       site = Nanoc::Site.new('.')
       exception = assert_raises(RuntimeError) do
         site.compile
       end
-      assert_equal "Could not read content/index.html because the file is not valid UTF-8.", exception.message
+      assert_equal 'Could not read content/index.html because the file is not valid UTF-8.', exception.message
 
       # Try with encoding = specific
       File.open('nanoc.yaml', 'w') { |io| io.write("meh: true\n") }
@@ -59,5 +70,4 @@ class Nanoc::CLI::Commands::CreateSiteTest < Nanoc::TestCase
       assert_match(/\/stylesheet.css/, File.read('output/index.html'))
     end
   end
-
 end
