@@ -1,5 +1,4 @@
 class Nanoc::CLI::Commands::SyncTest < Nanoc::TestCase
-
   def test_run
     with_site do
       File.open('lib/foo_data_source.rb', 'w') do |io|
@@ -16,7 +15,7 @@ class Nanoc::CLI::Commands::SyncTest < Nanoc::TestCase
       File.open('nanoc.yaml', 'w') do |io|
         io.write "data_sources:\n"
         io.write "  - type: sync_test_foo\n"
-        io.write "    items_root: /"
+        io.write '    items_root: /'
       end
 
       Nanoc::CLI.run %w( sync )
@@ -25,5 +24,4 @@ class Nanoc::CLI::Commands::SyncTest < Nanoc::TestCase
       assert_equal File.read('foo_source_data.yaml'), 'sync: true'
     end
   end
-
 end
