@@ -1,8 +1,7 @@
 # encoding: utf-8
 
 class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
-
-  def new_data_source(params=nil)
+  def new_data_source(params = nil)
     # Mock site
     site = Nanoc::Site.new({})
 
@@ -16,7 +15,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
   def test_create_object_not_at_root
     # Create item
     data_source = new_data_source
-    data_source.send(:create_object, 'foobar', 'content here', { :foo => 'bar' }, '/asdf/')
+    data_source.send(:create_object, 'foobar', 'content here', { foo: 'bar' }, '/asdf/')
 
     # Check file existance
     assert File.directory?('foobar')
@@ -32,7 +31,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
   def test_create_object_at_root
     # Create item
     data_source = new_data_source
-    data_source.send(:create_object, 'foobar', 'content here', { :foo => 'bar' }, '/')
+    data_source.send(:create_object, 'foobar', 'content here', { foo: 'bar' }, '/')
 
     # Check file existance
     assert File.directory?('foobar')
@@ -55,6 +54,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       def initialize(*stuff)
         @stuff = stuff
       end
+
       def ==(other)
         @stuff == other.stuff
       end
@@ -77,32 +77,32 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
         'test 1',
         { 'num' => 1, :filename => 'foo/bar.html',   :extension => 'html', :file => File.open('foo/bar.html') },
         '/bar/',
-        :binary => false, :mtime => File.mtime('foo/bar.html')
+        binary: false, mtime: File.mtime('foo/bar.html')
       ),
       klass.new(
         'test 2',
         { 'num' => 2, :filename => 'foo/b.c.html',   :extension => 'c.html', :file => File.open('foo/b.c.html') },
         '/b/',
-        :binary => false, :mtime => File.mtime('foo/b.c.html')
+        binary: false, mtime: File.mtime('foo/b.c.html')
       ),
       klass.new(
         'test 3',
         { 'num' => 3, :filename => 'foo/a/b/c.html', :extension => 'html', :file => File.open('foo/a/b/c.html') },
         '/a/b/c/',
-        :binary => false, :mtime => File.mtime('foo/a/b/c.html')
+        binary: false, mtime: File.mtime('foo/a/b/c.html')
       )
     ]
     actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass).sort_by { |i| i.stuff[0] }
 
     # Check
-    (0..expected_out.size-1).each do |i|
+    (0..expected_out.size - 1).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
       assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
       assert_equal expected_out[i].stuff[1][:file].path, actual_out[i].stuff[1][:file].path, 'file paths must match'
-      expected_out[i].stuff[1][:file].close;
+      expected_out[i].stuff[1][:file].close
       actual_out[i].stuff[1][:file].close
-      [ 'num', :filename, :extension ].each do |key|
+      ['num', :filename, :extension].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
@@ -114,7 +114,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Create sample files
     FileUtils.mkdir_p('foo')
-    File.open('foo/stuff.dat', 'w') { |io| io.write("random binary data") }
+    File.open('foo/stuff.dat', 'w') { |io| io.write('random binary data') }
 
     # Load
     items = data_source.send(:load_objects, 'foo', 'item', Nanoc::Item)
@@ -132,7 +132,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Create sample files
     FileUtils.mkdir_p('foo')
-    File.open('foo/stuff.dat', 'w') { |io| io.write("random binary data") }
+    File.open('foo/stuff.dat', 'w') { |io| io.write('random binary data') }
 
     # Load
     assert_raises(RuntimeError) do
@@ -142,7 +142,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
   def test_identifier_for_filename_allowing_periods_in_identifiers
     # Create data source
-    data_source = new_data_source(:allow_periods_in_identifiers => true)
+    data_source = new_data_source(allow_periods_in_identifiers: true)
 
     # Get input and expected output
     expected = {
@@ -198,10 +198,10 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       'foo/blah_index.yaml'  => '/foo/blah_index/'
     }
 
-    data_source = new_data_source(:allow_periods_in_identifiers => true)
+    data_source = new_data_source(allow_periods_in_identifiers: true)
     expectations.each_pair do |meta_filename, expected_identifier|
       content_filename = meta_filename.sub(/yaml$/, 'html')
-      [ meta_filename, content_filename ].each do |filename|
+      [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
           data_source.instance_eval { identifier_for_filename(filename) }
@@ -227,7 +227,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     data_source = new_data_source
     expectations.each_pair do |meta_filename, expected_identifier|
       content_filename = meta_filename.sub(/yaml$/, 'html')
-      [ meta_filename, content_filename ].each do |filename|
+      [meta_filename, content_filename].each do |filename|
         assert_equal(
           expected_identifier,
           data_source.instance_eval { identifier_for_filename(filename) }
@@ -246,7 +246,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       '/foo/index'            => '/foo/',
     }
 
-    data_source = new_data_source(:allow_periods_in_identifiers => true)
+    data_source = new_data_source(allow_periods_in_identifiers: true)
     expected.each_pair do |input, expected_output|
       actual_output = data_source.send(:identifier_for_filename, input)
       assert_equal(
@@ -278,7 +278,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
   def test_load_objects_allowing_periods_in_identifiers
     # Create data source
-    data_source = new_data_source(:allow_periods_in_identifiers => true)
+    data_source = new_data_source(allow_periods_in_identifiers: true)
 
     # Create a fake class
     klass = Class.new do
@@ -286,6 +286,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       def initialize(*stuff)
         @stuff = stuff
       end
+
       def ==(other)
         @stuff == other.stuff
       end
@@ -296,13 +297,13 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     FileUtils.mkdir_p('foo/a/b')
     File.open('foo/a/b/c.yaml',     'w') { |io| io.write("---\nnum: 1\n") }
     File.open('foo/b.c.yaml',       'w') { |io| io.write("---\nnum: 2\n") }
-    File.open('foo/b.c.html',       'w') { |io| io.write("test 2")        }
-    File.open('foo/car.html',       'w') { |io| io.write("test 3")        }
-    File.open('foo/ugly.yaml~',     'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html~',     'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.orig', 'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.rej',  'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.bak',  'w') { |io| io.write("blah")          }
+    File.open('foo/b.c.html',       'w') { |io| io.write('test 2')        }
+    File.open('foo/car.html',       'w') { |io| io.write('test 3')        }
+    File.open('foo/ugly.yaml~',     'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html~',     'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.orig', 'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.rej',  'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.bak',  'w') { |io| io.write('blah')          }
 
     # Get expected output
     expected_out = [
@@ -316,7 +317,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :file             => nil
         },
         '/a/b/c/',
-        :binary => false, :mtime => File.mtime('foo/a/b/c.yaml')
+        binary: false, mtime: File.mtime('foo/a/b/c.yaml')
       ),
       klass.new(
         'test 2',
@@ -328,18 +329,18 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :file             => File.open('foo/b.c.html')
         },
         '/b.c/',
-        :binary => false, :mtime => File.mtime('foo/b.c.html') > File.mtime('foo/b.c.yaml') ? File.mtime('foo/b.c.html') : File.mtime('foo/b.c.yaml')
+        binary: false, mtime: File.mtime('foo/b.c.html') > File.mtime('foo/b.c.yaml') ? File.mtime('foo/b.c.html') : File.mtime('foo/b.c.yaml')
       ),
       klass.new(
         'test 3',
         {
-          :content_filename => 'foo/car.html',
-          :meta_filename    => nil,
-          :extension        => 'html',
-          :file             => File.open('foo/car.html')
+          content_filename: 'foo/car.html',
+          meta_filename: nil,
+          extension: 'html',
+          file: File.open('foo/car.html')
         },
         '/car/',
-        :binary => false, :mtime => File.mtime('foo/car.html')
+        binary: false, mtime: File.mtime('foo/car.html')
       )
     ]
 
@@ -347,7 +348,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass).sort_by { |i| i.stuff[2] }
 
     # Check
-    (0..expected_out.size-1).each do |i|
+    (0..expected_out.size - 1).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
       assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
@@ -358,7 +359,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       actual_file.close unless actual_file.nil?
       expected_file.close unless expected_file.nil?
 
-      [ 'num', :content_filename, :meta_filename, :extension ].each do |key|
+      ['num', :content_filename, :meta_filename, :extension].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
@@ -374,6 +375,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       def initialize(*stuff)
         @stuff = stuff
       end
+
       def ==(other)
         @stuff == other.stuff
       end
@@ -384,13 +386,13 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     FileUtils.mkdir_p('foo/a/b')
     File.open('foo/a/b/c.yaml',     'w') { |io| io.write("---\nnum: 1\n") }
     File.open('foo/b.yaml',         'w') { |io| io.write("---\nnum: 2\n") }
-    File.open('foo/b.html.erb',     'w') { |io| io.write("test 2")        }
-    File.open('foo/car.html',       'w') { |io| io.write("test 3")        }
-    File.open('foo/ugly.yaml~',     'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html~',     'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.orig', 'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.rej',  'w') { |io| io.write("blah")          }
-    File.open('foo/ugly.html.bak',  'w') { |io| io.write("blah")          }
+    File.open('foo/b.html.erb',     'w') { |io| io.write('test 2')        }
+    File.open('foo/car.html',       'w') { |io| io.write('test 3')        }
+    File.open('foo/ugly.yaml~',     'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html~',     'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.orig', 'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.rej',  'w') { |io| io.write('blah')          }
+    File.open('foo/ugly.html.bak',  'w') { |io| io.write('blah')          }
 
     # Get expected output
     expected_out = [
@@ -404,7 +406,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :file             => nil
         },
         '/a/b/c/',
-        :binary => false, :mtime => File.mtime('foo/a/b/c.yaml')
+        binary: false, mtime: File.mtime('foo/a/b/c.yaml')
       ),
       klass.new(
         'test 2',
@@ -416,18 +418,18 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
           :file             => File.open('foo/b.html.erb')
         },
         '/b/',
-        :binary => false, :mtime => File.mtime('foo/b.html.erb') > File.mtime('foo/b.yaml') ? File.mtime('foo/b.html.erb') : File.mtime('foo/b.yaml')
+        binary: false, mtime: File.mtime('foo/b.html.erb') > File.mtime('foo/b.yaml') ? File.mtime('foo/b.html.erb') : File.mtime('foo/b.yaml')
       ),
       klass.new(
         'test 3',
         {
-          :content_filename => 'foo/car.html',
-          :meta_filename    => nil,
-          :extension        => 'html',
-          :file             => File.open('foo/car.html')
+          content_filename: 'foo/car.html',
+          meta_filename: nil,
+          extension: 'html',
+          file: File.open('foo/car.html')
         },
         '/car/',
-        :binary => false, :mtime => File.mtime('foo/car.html')
+        binary: false, mtime: File.mtime('foo/car.html')
       )
     ]
 
@@ -435,7 +437,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     actual_out = data_source.send(:load_objects, 'foo', 'The Foo', klass).sort_by { |i| i.stuff[2] }
 
     # Check
-    (0..expected_out.size-1).each do |i|
+    (0..expected_out.size - 1).each do |i|
       assert_equal expected_out[i].stuff[0], actual_out[i].stuff[0], 'content must match'
       assert_equal expected_out[i].stuff[2], actual_out[i].stuff[2], 'identifier must match'
       assert_equal expected_out[i].stuff[3][:mtime], actual_out[i].stuff[3][:mtime], 'mtime must match'
@@ -446,7 +448,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       actual_file.close unless actual_file.nil?
       expected_file.close unless expected_file.nil?
 
-      [ 'num', :content_filename, :meta_filename, :extension ].each do |key|
+      ['num', :content_filename, :meta_filename, :extension].each do |key|
         assert_equal expected_out[i].stuff[1][key], actual_out[i].stuff[1][key], "attribute key #{key} must match"
       end
     end
@@ -454,17 +456,17 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
   def test_create_object_allowing_periods_in_identifiers
     # Create data source
-    data_source = new_data_source(:allow_periods_in_identifiers => true)
+    data_source = new_data_source(allow_periods_in_identifiers: true)
 
     # Create object without period
-    data_source.send(:create_object, 'foo', 'some content', { :some => 'attributes' }, '/asdf/')
+    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/asdf/')
     assert File.file?('foo/asdf.html')
     data = data_source.send(:parse, 'foo/asdf.html', nil, 'moo')
     assert_equal({ 'some' => 'attributes' }, data[0])
     assert_equal('some content',             data[1])
 
     # Create object with period
-    data_source.send(:create_object, 'foo', 'some content', { :some => 'attributes' }, '/as.df/')
+    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/as.df/')
     assert File.file?('foo/as.df.html')
     data = data_source.send(:parse, 'foo/as.df.html', nil, 'moo')
     assert_equal({ 'some' => 'attributes' }, data[0])
@@ -476,7 +478,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     data_source = new_data_source
 
     # Create object without period
-    data_source.send(:create_object, 'foo', 'some content', { :some => 'attributes' }, '/asdf/')
+    data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/asdf/')
     assert File.file?('foo/asdf.html')
     data = data_source.send(:parse, 'foo/asdf.html', nil, 'moo')
     assert_equal({ 'some' => 'attributes' }, data[0])
@@ -484,7 +486,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
     # Create object with period
     assert_raises(RuntimeError) do
-      data_source.send(:create_object, 'foo', 'some content', { :some => 'attributes' }, '/as.df/')
+      data_source.send(:create_object, 'foo', 'some content', { some: 'attributes' }, '/as.df/')
     end
   end
 
@@ -517,8 +519,8 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
   def test_compile_iso_8859_1_site
     # Check encoding
-    if !''.respond_to?(:encode)
-      skip "Test only works on 1.9.x"
+    unless ''.respond_to?(:encode)
+      skip 'Test only works on 1.9.x'
       return
     end
 
@@ -526,7 +528,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     data_source = new_data_source
 
     # Create item
-    data_source.create_item("Hëllö", {}, '/foo/')
+    data_source.create_item('Hëllö', {}, '/foo/')
 
     # Parse
     begin
@@ -536,7 +538,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       items = data_source.items
 
       assert_equal 1, items.size
-      assert_equal Encoding.find("UTF-8"), items[0].raw_content.encoding
+      assert_equal Encoding.find('UTF-8'), items[0].raw_content.encoding
     ensure
       Encoding.default_external = original_default_external_encoding
     end
@@ -544,8 +546,8 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
 
   def test_compile_iso_8859_1_site_with_explicit_encoding
     # Check encoding
-    if !''.respond_to?(:encode)
-      skip "Test only works on 1.9.x"
+    unless ''.respond_to?(:encode)
+      skip 'Test only works on 1.9.x'
       return
     end
 
@@ -558,7 +560,7 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
       original_default_external_encoding = Encoding.default_external
       Encoding.default_external = 'ISO-8859-1'
 
-      data_source.create_item("Hëllö", {}, '/foo/')
+      data_source.create_item('Hëllö', {}, '/foo/')
     ensure
       Encoding.default_external = original_default_external_encoding
     end
@@ -566,7 +568,6 @@ class Nanoc::DataSources::FilesystemUnifiedTest < Nanoc::TestCase
     # Parse
     items = data_source.items
     assert_equal 1, items.size
-    assert_equal Encoding.find("UTF-8"), items[0].raw_content.encoding
+    assert_equal Encoding.find('UTF-8'), items[0].raw_content.encoding
   end
-
 end
