@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
-
   def test_run_ok
     VCR.use_cassette('html_run_ok') do
       with_site do |site|
@@ -34,9 +33,11 @@ class Nanoc::Extra::Checking::Checks::HTMLTest < Nanoc::TestCase
 
         # Check
         refute check.issues.empty?
+        assert_equal 2, check.issues.size
+        assert_equal 'line 1: no document type declaration; will parse without validation: <h2>Hi!</h1>', check.issues.to_a[0].description
+        assert_equal 'line 1: end tag for element "H1" which is not open: <h2>Hi!</h1>', check.issues.to_a[1].description
+          check.issues.to_a[0].description
       end
     end
   end
-
 end
-
