@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Extra::PiperTest < Nanoc::TestCase
-
   def test_basic
     stdout = StringIO.new
     stderr = StringIO.new
@@ -11,7 +10,7 @@ class Nanoc::Extra::PiperTest < Nanoc::TestCase
     File.open('foo.txt', 'w') { |io| io.write('hi') }
     File.open('bar.txt', 'w') { |io| io.write('ho') }
 
-    piper = Nanoc::Extra::Piper.new(:stdout => stdout, :stderr => stderr)
+    piper = Nanoc::Extra::Piper.new(stdout: stdout, stderr: stderr)
     piper.run(cmd, nil)
 
     assert_match(/foo\.txt/, stdout.string)
@@ -26,7 +25,7 @@ class Nanoc::Extra::PiperTest < Nanoc::TestCase
     input = 'Hello World!'
     cmd = %w( cat )
 
-    piper = Nanoc::Extra::Piper.new(:stdout => stdout, :stderr => stderr)
+    piper = Nanoc::Extra::Piper.new(stdout: stdout, stderr: stderr)
     piper.run(cmd, input)
 
     assert_equal(input, stdout.string)
@@ -39,10 +38,9 @@ class Nanoc::Extra::PiperTest < Nanoc::TestCase
 
     cmd = %w( cat kafhawilgoiwaejagoualjdsfilofiewaguihaifeowuiga )
 
-    piper = Nanoc::Extra::Piper.new(:stdout => stdout, :stderr => stderr)
+    piper = Nanoc::Extra::Piper.new(stdout: stdout, stderr: stderr)
     assert_raises(Nanoc::Extra::Piper::Error) do
       piper.run(cmd, nil)
     end
   end
-
 end
