@@ -1,19 +1,18 @@
 # encoding: utf-8
 
 class Nanoc::Extra::Validators::W3CTest < Nanoc::TestCase
-
   def test_simple
     if_have 'w3c_validators' do
-      with_site do |site|
+      with_site do |_site|
         # Create some sample files
-        %w{ foo bar baz }.each do |filename|
-          %w{ xxx yyy }.each do |extension|
-            File.open("output/#{filename}.#{extension}", 'w') { |io| io.write("hello") }
+        %w(foo bar baz).each do |filename|
+          %w(xxx yyy).each do |extension|
+            File.open("output/#{filename}.#{extension}", 'w') { |io| io.write('hello') }
           end
         end
 
         # Create validator
-        w3c = Nanoc::Extra::Validators::W3C.new('.', [ :html ])
+        w3c = Nanoc::Extra::Validators::W3C.new('.', [:html])
 
         # Run
         w3c.run
@@ -23,9 +22,9 @@ class Nanoc::Extra::Validators::W3CTest < Nanoc::TestCase
 
   def test_with_unknown_types
     if_have 'w3c_validators' do
-      with_site do |site|
+      with_site do |_site|
         # Create validator
-        w3c = Nanoc::Extra::Validators::W3C.new('.', [ :foo ])
+        w3c = Nanoc::Extra::Validators::W3C.new('.', [:foo])
 
         # Test
         exception = assert_raises Nanoc::Errors::GenericTrivial do
@@ -35,5 +34,4 @@ class Nanoc::Extra::Validators::W3CTest < Nanoc::TestCase
       end
     end
   end
-
 end
