@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Filters::CoffeeScriptTest < Nanoc::TestCase
-
   def test_filter
     if_have 'coffee-script' do
       # Create filter
@@ -9,8 +8,7 @@ class Nanoc::Filters::CoffeeScriptTest < Nanoc::TestCase
 
       # Run filter (no assigns)
       result = filter.setup_and_run('alert 42')
-      assert_equal("(function() { alert(42); }).call(this); ", result.gsub(/\s+/, ' '))
+      assert_equal('(function() { alert(42); }).call(this); ', result.gsub(/\s+/, ' '))
     end
   end
-
 end
