@@ -1,15 +1,14 @@
 # encoding: utf-8
 
 class Nanoc::Filters::RedClothTest < Nanoc::TestCase
-
   def test_filter
     if_have 'redcloth' do
       # Get filter
       filter = ::Nanoc::Filters::RedCloth.new
 
       # Run filter
-      result = filter.setup_and_run("h1. Foo")
-      assert_equal("<h1>Foo</h1>", result)
+      result = filter.setup_and_run('h1. Foo')
+      assert_equal('<h1>Foo</h1>', result)
     end
   end
 
@@ -19,13 +18,12 @@ class Nanoc::Filters::RedClothTest < Nanoc::TestCase
       filter = ::Nanoc::Filters::RedCloth.new
 
       # Run filter without options
-      result = filter.setup_and_run("I am a member of SPECTRE.")
+      result = filter.setup_and_run('I am a member of SPECTRE.')
       assert_equal("<p>I am a member of <span class=\"caps\">SPECTRE</span>.</p>", result)
 
       # Run filter with options
-      result = filter.setup_and_run("I am a member of SPECTRE.", :no_span_caps => true)
-      assert_equal("<p>I am a member of SPECTRE.</p>", result)
+      result = filter.setup_and_run('I am a member of SPECTRE.', no_span_caps: true)
+      assert_equal('<p>I am a member of SPECTRE.</p>', result)
     end
   end
-
 end
