@@ -1,8 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
-
-
   def test_filter_html_with_double_quotes
     # Create filter with mock item
     filter = Nanoc::Filters::RelativizePaths.new
@@ -19,11 +17,11 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
     end
 
     # Set content
-    raw_content      = %[<a href="/foo">foo</a>]
-    expected_content = %[<a href="../..">foo</a>]
+    raw_content      = %(<a href="/foo">foo</a>)
+    expected_content = %(<a href="../..">foo</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -43,11 +41,11 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
     end
 
     # Set content
-    raw_content      = %[<a href='/foo'>foo</a>]
-    expected_content = %[<a href="../..">foo</a>]
+    raw_content      = %(<a href='/foo'>foo</a>)
+    expected_content = %(<a href="../..">foo</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -67,11 +65,11 @@ class Nanoc::Filters::RelativizePathsTest < Nanoc::TestCase
     end
 
     # Set content
-    raw_content      = %[<a href=/foo>foo</a>]
-    expected_content = %[<a href="../..">foo</a>]
+    raw_content      = %(<a href=/foo>foo</a>)
+    expected_content = %(<a href="../..">foo</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -106,7 +104,7 @@ EOS
     expected_match_1 = %r{\A\s*<!DOCTYPE html\s*>\s*<html>\s*<head>(.|\s)*<title>Hello</title>\s*</head>\s*<body>\s*<a href="../..">foo</a>\s*</body>\s*</html>\s*\Z}m
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_match(expected_match_0, actual_content)
     assert_match(expected_match_1, actual_content)
   end
@@ -127,11 +125,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="/foo">foo</a> <a href="/bar">bar</a>]
-    expected_content = %[<a href="../..">foo</a> <a href="../../../bar">bar</a>]
+    raw_content      = %(<a href="/foo">foo</a> <a href="/bar">bar</a>)
+    expected_content = %(<a href="../..">foo</a> <a href="../../../bar">bar</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -151,11 +149,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="/"><img src="/bar.png" /></a>]
-    expected_content = %[<a href="../../../"><img src="../../../bar.png"></a>]
+    raw_content      = %(<a href="/"><img src="/bar.png" /></a>)
+    expected_content = %(<a href="../../../"><img src="../../../bar.png"></a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -175,11 +173,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[stuff href="/foo" more stuff]
-    expected_content = %[stuff href="/foo" more stuff]
+    raw_content      = %(stuff href="/foo" more stuff)
+    expected_content = %(stuff href="/foo" more stuff)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -199,11 +197,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="/">foo</a>]
-    expected_content = %[<a href="../../">foo</a>]
+    raw_content      = %(<a href="/">foo</a>)
+    expected_content = %(<a href="../../">foo</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -223,11 +221,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="//example.com/">example.com</a>]
-    expected_content = %[<a href="//example.com/">example.com</a>]
+    raw_content      = %(<a href="//example.com/">example.com</a>)
+    expected_content = %(<a href="//example.com/">example.com</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -247,11 +245,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="#max-payne">Max Payne</a>]
-    expected_content = %[<a href="#max-payne">Max Payne</a>]
+    raw_content      = %(<a href="#max-payne">Max Payne</a>)
+    expected_content = %(<a href="#max-payne">Max Payne</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -271,11 +269,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="http://example.com/">Example</a>]
-    expected_content = %[<a href="http://example.com/">Example</a>]
+    raw_content      = %(<a href="http://example.com/">Example</a>)
+    expected_content = %(<a href="http://example.com/">Example</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -295,11 +293,11 @@ EOS
     end
 
     # Set content
-    raw_content      = %[<a href="example">Example</a>]
-    expected_content = %[<a href="example">Example</a>]
+    raw_content      = %(<a href="example">Example</a>)
+    expected_content = %(<a href="example">Example</a>)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
 
@@ -318,21 +316,20 @@ EOS
       @item_rep.path = '/woof/meow/'
     end
 
-    raw_content    = %[<object data="/example"><param name="movie" content="/example"></object>]
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    raw_content    = %(<object data="/example"><param name="movie" content="/example"></object>)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
 
     assert_match(/<object data="..\/..\/example">/, actual_content)
     assert_match(/<param (name="movie" )?content="..\/..\/example"/, actual_content)
   end
 
-
   def test_filter_implicit
     # Create filter with mock item
     filter = Nanoc::Filters::RelativizePaths.new
 
     # Test
     assert_raises(RuntimeError) do
-      filter.setup_and_run("moo")
+      filter.setup_and_run('moo')
     end
   end
 
@@ -356,7 +353,7 @@ EOS
     expected_content = %[background: url("../background.png");]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -380,7 +377,7 @@ EOS
     expected_content = %[background: url('../background.png');]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -404,7 +401,7 @@ EOS
     expected_content = %[background: url(../background.png);]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -428,7 +425,7 @@ EOS
     expected_content = %[background: url(../a.png) url(../b.png);]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -455,7 +452,7 @@ EOS
     expected_content = %[background: url(../../);]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -479,7 +476,7 @@ EOS
     expected_content = %[background: url(//example.com);]
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :css)
+    actual_content = filter.setup_and_run(raw_content, type: :css)
     assert_equal(expected_content, actual_content)
   end
 
@@ -508,7 +505,7 @@ EOS
 </foo>
 XML
 
-      actual_content = filter.setup_and_run(raw_content, :type => :xml, :select => ['*/@boo'])
+      actual_content = filter.setup_and_run(raw_content, type: :xml, select: ['*/@boo'])
 
       assert_match(expected, actual_content)
     end
@@ -537,7 +534,7 @@ XML
 </foo>
 XML
 
-      actual_content = filter.setup_and_run(raw_content, :type => :xml, :select => ['far/@href'])
+      actual_content = filter.setup_and_run(raw_content, type: :xml, select: ['far/@href'])
 
       assert_match(/<foo>/, actual_content)
       assert_match(/<bar><far href="..\/..">baz<\/far><\/bar>/, actual_content)
@@ -568,9 +565,9 @@ XML
 XML
 
       actual_content = filter.setup_and_run(raw_content, {
-        :type => :xml,
-        :namespaces => {:ex => 'http://example.org'},
-        :select => ['ex:a/@href']
+        type: :xml,
+        namespaces: { ex: 'http://example.org' },
+        select: ['ex:a/@href']
       })
 
       assert_match(/<foo xmlns="http:\/\/example.org">/,    actual_content)
@@ -609,7 +606,7 @@ XML
 </html>
 XML
 
-      actual_content = filter.setup_and_run(raw_content, :type => :xhtml)
+      actual_content = filter.setup_and_run(raw_content, type: :xhtml)
 
       assert_match(/<link[^>]*href="..\/..\/..\/css"[^>]*\/>/, actual_content)
       assert_match(/<script src="..\/..\/..\/js">/,            actual_content)
@@ -646,7 +643,7 @@ XML
         %r{\A\s*<a href="../..">bar</a>\s*<p>\s*<img src="../../../img" />\s*</p>\s*\Z}m
 
       # Test
-      actual_content = filter.setup_and_run(raw_content.freeze, :type => :xhtml)
+      actual_content = filter.setup_and_run(raw_content.freeze, type: :xhtml)
       assert_match(expected_content, actual_content)
     end
   end
@@ -668,21 +665,21 @@ XML
       end
 
       # Set content
-      raw_content = %[
+      raw_content = %(
 <link rel="stylesheet" href="/foo.css" />
 <!--[if lt IE 9]>
     <script src="/js/lib/html5shiv.js"></script>
 <![endif]-->
-]
 
-      actual_content = filter.setup_and_run(raw_content.freeze, :type => :xhtml)
+)
+
+      actual_content = filter.setup_and_run(raw_content.freeze, type: :xhtml)
 
       assert_match(/<link (rel="stylesheet" )?href="..\/..\/foo.css" /,      actual_content)
       assert_match(/<script src="..\/..\/js\/lib\/html5shiv.js"><\/script>/, actual_content)
     end
   end
 
-
   def test_filter_fragment_html_with_comments
     if_have 'nokogiri' do
       # Create filter with mock item
@@ -700,15 +697,16 @@ XML
       end
 
       # Set content
-      raw_content = %[
+      raw_content = %(
 <!--[if lt IE 9]>
     <script src="/js/lib/html5shiv.js"></script>
 <![endif]-->
-]
+
+)
 
       # Test
-      actual_content = filter.setup_and_run(raw_content.freeze, :type => :html)
-      assert actual_content.include? %[<script src="../../js/lib/html5shiv.js">]
+      actual_content = filter.setup_and_run(raw_content.freeze, type: :html)
+      assert actual_content.include? %(<script src="../../js/lib/html5shiv.js">)
     end
   end
 
@@ -728,12 +726,11 @@ XML
     end
 
     # Set content
-    raw_content      = %[&lt;!DOCTYPE html>]
-    expected_content = %[&lt;!DOCTYPE html&gt;]
+    raw_content      = %(&lt;!DOCTYPE html>)
+    expected_content = %(&lt;!DOCTYPE html&gt;)
 
     # Test
-    actual_content = filter.setup_and_run(raw_content, :type => :html)
+    actual_content = filter.setup_and_run(raw_content, type: :html)
     assert_equal(expected_content, actual_content)
   end
-
 end
