@@ -1,11 +1,10 @@
 # encoding: utf-8
 
 class Nanoc::Filters::SassTest < Nanoc::TestCase
-
   def test_filter
     if_have 'sass' do
       # Get filter
-      filter = create_filter({ :foo => 'bar' })
+      filter = create_filter({ foo: 'bar' })
 
       # Run filter
       result = filter.setup_and_run(".foo #bar\n  color: #f00")
@@ -16,14 +15,14 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
   def test_filter_with_params
     if_have 'sass' do
       # Create filter
-      filter = create_filter({ :foo => 'bar' })
+      filter = create_filter({ foo: 'bar' })
 
       # Check with compact
-      result = filter.setup_and_run(".foo #bar\n  color: #f00", :style => 'compact')
+      result = filter.setup_and_run(".foo #bar\n  color: #f00", style: 'compact')
       assert_match(/^\.foo #bar[\s]*\{[\s]*color:\s*(red|#f00);?[\s]*\}/m, result)
 
       # Check with compressed
-      result = filter.setup_and_run(".foo #bar\n  color: #f00", :style => 'compressed')
+      result = filter.setup_and_run(".foo #bar\n  color: #f00", style: 'compressed')
       assert_match(/^\.foo #bar[\s]*\{[\s]*color:\s*(red|#f00);?[\s]*\}/m, result)
     end
   end
@@ -64,8 +63,8 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
       filter = create_filter
 
       # Create sample file
-      File.open('moo.sass', 'w') { |io| io.write %Q{@import subdir/relative} }
-      FileUtils.mkdir_p("subdir")
+      File.open('moo.sass', 'w') { |io| io.write %(@import subdir/relative) }
+      FileUtils.mkdir_p('subdir')
       File.open('subdir/relative.sass', 'w') { |io| io.write "body\n  color: red" }
 
       # Run filter
@@ -251,7 +250,7 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
 
         # Check
         output_files = Dir['output/**/*'].select { |f| File.file?(f) }
-        assert_equal [ 'output/style/super/main.css' ], output_files
+        assert_equal ['output/style/super/main.css'], output_files
         assert_match(/^p\s*\{\s*color:\s*red;?\s*\}/, File.read('output/style/super/main.css'))
 
         # Update included file
@@ -265,24 +264,34 @@ class Nanoc::Filters::SassTest < Nanoc::TestCase
 
         # Recheck
         output_files = Dir['output/**/*'].select { |f| File.file?(f) }
-        assert_equal [ 'output/style/super/main.css' ], output_files
+        assert_equal ['output/style/super/main.css'], output_files
         assert_match(/^p\s*\{\s*color:\s*blue;?\s*\}/, File.read('output/style/super/main.css'))
       end
     end
   end
 
-private
+  def test_sass_without_filter
+    if_have 'sass' do
+      File.open('_morestuff.sass', 'w') do |io|
+        io.write("p\n  color: blue")
+      end
 
-  def create_filter(params={})
-    FileUtils.mkdir_p('content')
-    File.open('content/xyzzy.sass', 'w') { |io| io.write('p\n  color: green')}
-
-    items = [ Nanoc::Item.new(
-      'blah',
-      { :content_filename => 'content/xyzzy.sass' },
-      '/blah/') ]
-    params = { :item => items[0], :items => items }.merge(params)
-    ::Nanoc::Filters::Sass.new(params)
+      options = { :filename => File.join(Dir.getwd, 'test.sass') }
+      ::Sass::Engine.new('@import "morestuff"', options).render
+    end
   end
 
+  private
+
+  def create_filter(params = {})
+    FileUtils.mkdir_p('content')
+    File.open('content/xyzzy.sass', 'w') { |io| io.write('p\n  color: green') }
+
+    items = [Nanoc::Item.new(
+      'blah',
+      { content_filename: 'content/xyzzy.sass' },
+      '/blah/')]
+    params = { item: items[0], items: items }.merge(params)
+    ::Nanoc::Filters::Sass.new(params)
+  end
 end
