@@ -1,14 +1,13 @@
 # encoding: utf-8
 
 class Nanoc::Filters::UglifyJSTest < Nanoc::TestCase
-
   def test_filter
     if_have 'uglifier' do
       # Create filter
       filter = ::Nanoc::Filters::UglifyJS.new
 
       # Run filter
-      input = "foo = 1; (function(bar) { if (true) alert(bar); })(foo)"
+      input = 'foo = 1; (function(bar) { if (true) alert(bar); })(foo)'
       result = filter.setup_and_run(input)
       assert_match(/foo=1,function\((.)\)\{alert\(\1\)\}\(foo\);/, result)
     end
@@ -19,12 +18,11 @@ class Nanoc::Filters::UglifyJSTest < Nanoc::TestCase
       filter = ::Nanoc::Filters::UglifyJS.new
       input = "if(donkey) alert('It is a donkey!');"
 
-      result = filter.setup_and_run(input, :output => { :beautify => false })
+      result = filter.setup_and_run(input, output: { beautify: false })
       assert_equal 'donkey&&alert("It is a donkey!");', result
 
-      result = filter.setup_and_run(input, :output => { :beautify => true })
+      result = filter.setup_and_run(input, output: { beautify: true })
       assert_equal 'donkey && alert("It is a donkey!");', result
     end
   end
-
 end
