@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Filters::YUICompressorTest < Nanoc::TestCase
-
   def test_filter_javascript
     if_have 'yuicompressor' do
       filter = ::Nanoc::Filters::YUICompressor.new
@@ -16,11 +15,11 @@ class Nanoc::Filters::YUICompressorTest < Nanoc::TestCase
         }
       JAVASCRIPT
 
-      result = filter.setup_and_run(sample_js, { :type => 'js', :munge => true })
-      assert_match "function factorial(c){var a=1;for(var b=2;b<=c;b++){a*=b}return a};", result
+      result = filter.setup_and_run(sample_js, { type: 'js', munge: true })
+      assert_match 'function factorial(c){var a=1;for(var b=2;b<=c;b++){a*=b}return a};', result
 
-      result = filter.setup_and_run(sample_js, { :type => 'js', :munge => false })
-      assert_match "function factorial(n){var result=1;for(var i=2;i<=n;i++){result*=i}return result};", result
+      result = filter.setup_and_run(sample_js, { type: 'js', munge: false })
+      assert_match 'function factorial(n){var result=1;for(var i=2;i<=n;i++){result*=i}return result};', result
     end
   end
 
@@ -34,9 +33,8 @@ class Nanoc::Filters::YUICompressorTest < Nanoc::TestCase
         }
       CSS
 
-      result = filter.setup_and_run(sample_css, { :type => 'css' })
-      assert_match "*{margin:0}", result
+      result = filter.setup_and_run(sample_css, { type: 'css' })
+      assert_match '*{margin:0}', result
     end
   end
-
 end
