@@ -4,7 +4,7 @@
 require File.dirname(__FILE__) + '/gem_loader.rb'
 
 # Load unit testing stuff
-require 'minitest/unit'
+require 'minitest/test'
 require 'minitest/spec'
 require 'minitest/mock'
 require 'mocha/setup'
@@ -30,7 +30,6 @@ VCR.configure do |c|
 end
 
 module Nanoc::TestHelpers
-
   LIB_DIR = File.expand_path(File.dirname(__FILE__) + '/../lib')
 
   def disable_nokogiri?
@@ -40,7 +39,7 @@ module Nanoc::TestHelpers
   def if_have(*libs)
     libs.each do |lib|
       if defined?(RUBY_ENGINE) && RUBY_ENGINE == 'jruby' && lib == 'nokogiri' && disable_nokogiri?
-        skip "Pure Java Nokogiri has issues that cause problems with nanoc (see https://github.com/nanoc/nanoc/pull/422) -- run without DISABLE_NOKOGIRI to enable Nokogiri tests"
+        skip 'Pure Java Nokogiri has issues that cause problems with nanoc (see https://github.com/nanoc/nanoc/pull/422) -- run without DISABLE_NOKOGIRI to enable Nokogiri tests'
         return
       end
 
@@ -56,15 +55,13 @@ module Nanoc::TestHelpers
   end
 
   def if_implemented
-    begin
-      yield
-    rescue NotImplementedError, NameError
-      skip $!
-      return
-    end
+    yield
+  rescue NotImplementedError, NameError
+    skip $ERROR_INFO
+    return
   end
 
-  def with_site(params={})
+  def with_site(params = {})
     # Build site name
     site_name = params[:name]
     if site_name.nil?
@@ -161,7 +158,7 @@ EOS
     end
   end
 
-  def capturing_stdio(&block)
+  def capturing_stdio(&_block)
     # Store
     orig_stdout = $stdout
     orig_stderr = $stderr
@@ -170,7 +167,7 @@ EOS
     $stdout = StringIO.new
     $stderr = StringIO.new
     yield
-    { :stdout => $stdout.string, :stderr => $stderr.string }
+    { stdout: $stdout.string, stderr: $stderr.string }
   ensure
     # Restore
     $stdout = orig_stdout
@@ -182,7 +179,7 @@ EOS
     P(object).tags(:example).each do |example|
       # Classify
       lines = example.text.lines.map do |line|
-        [ line =~ /^\s*# ?=>/ ? :result : :code, line ]
+        [line =~ /^\s*# ?=>/ ? :result : :code, line]
       end
 
       # Join
@@ -194,7 +191,7 @@ EOS
           pieces << line
         end
       end
-      lines = pieces.map { |p| p.last }
+      lines = pieces.map(&:last)
 
       # Test
       b = binding
@@ -210,14 +207,14 @@ EOS
 
   def assert_contains_exactly(expected, actual)
     assert_equal expected.size, actual.size,
-      'Expected %s to be of same size as %s' % [actual.inspect, expected.inspect]
+      format('Expected %s to be of same size as %s', actual.inspect, expected.inspect)
     remaining = actual.dup.to_a
     expected.each do |e|
       index = remaining.index(e)
       remaining.delete_at(index) if index
     end
     assert remaining.empty?,
-      'Expected %s to contain all the elements of %s' % [actual.inspect, expected.inspect]
+      format('Expected %s to contain all the elements of %s', actual.inspect, expected.inspect)
   end
 
   def assert_raises_frozen_error
@@ -225,24 +222,24 @@ EOS
     assert_match(/(^can't modify frozen |^unable to modify frozen object$)/, error.message)
   end
 
-  def with_env_vars(hash, &block)
+  def with_env_vars(hash, &_block)
     orig_env_hash = ENV.to_hash
-    hash.each_pair { |k,v| ENV[k] = v }
+    hash.each_pair { |k, v| ENV[k] = v }
     yield
   ensure
-    orig_env_hash.each_pair { |k,v| ENV[k] = v }
+    orig_env_hash.each_pair { |k, v| ENV[k] = v }
   end
 
   def on_windows?
     Nanoc.on_windows?
   end
 
-  def have_command?(cmd)
-    which, null = on_windows? ? ["where", "NUL"] : ["which", "/dev/null"]
+  def command?(cmd)
+    which, null = on_windows? ? %w(where NUL) : ['which', '/dev/null']
     system("#{which} #{cmd} > #{null} 2>&1")
   end
 
-  def have_symlink?
+  def symlinks_supported?
     File.symlink nil, nil
   rescue NotImplementedError
     return false
@@ -251,28 +248,25 @@ EOS
   end
 
   def skip_unless_have_command(cmd)
-    skip "Could not find external command \"#{cmd}\"" unless have_command?(cmd)
+    skip "Could not find external command \"#{cmd}\"" unless command?(cmd)
   end
 
-  def skip_unless_have_symlink
-    skip "Symlinks are not supported by Ruby on Windows" unless have_symlink?
+  def skip_unless_symlinks_supported
+    skip 'Symlinks are not supported by Ruby on Windows' unless symlinks_supported?
   end
-
 end
 
-class Nanoc::TestCase < MiniTest::Unit::TestCase
-
+class Nanoc::TestCase < Minitest::Test
   include Nanoc::TestHelpers
-
 end
 
 # Unexpected system exit is unexpected
-::MiniTest::Unit::TestCase::PASSTHROUGH_EXCEPTIONS.delete(SystemExit)
+::Minitest::Test::PASSTHROUGH_EXCEPTIONS.delete(SystemExit)
 
 # A more precise inspect method for Time improves assert failure messages.
 #
 class Time
   def inspect
-    strftime("%a %b %d %H:%M:%S.#{"%06d" % usec} %Z %Y")
+    strftime("%a %b %d %H:%M:%S.#{format('%06d', usec)} %Z %Y")
   end
 end
