@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
-
   include Nanoc::Helpers::Blogging
   include Nanoc::Helpers::Text
 
@@ -14,7 +13,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     item.stubs(:[]).with(:custom_path_in_feed).returns(nil)
     item.stubs(:[]).with(:custom_url_in_feed).returns(nil)
     item.stubs(:[]).with(:excerpt).returns(nil)
-    item.stubs(:path).returns("/item/")
+    item.stubs(:path).returns('/item/')
     item.stubs(:[]).with(:author_name).returns(nil)
     item.stubs(:[]).with(:author_uri).returns(nil)
     item.stubs(:compiled_content).returns('item content')
@@ -32,17 +31,17 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [
       Nanoc::Item.new(
         'blah',
-        { :kind => 'item' },
+        { kind: 'item' },
         '/0/'
       ),
       Nanoc::Item.new(
         'blah blah',
-        { :kind => 'article' },
+        { kind: 'article' },
         '/1/'
       ),
       Nanoc::Item.new(
         'blah blah blah',
-        { :kind => 'article' },
+        { kind: 'article' },
         '/2/'
       )
     ]
@@ -61,17 +60,17 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     @items = [
       Nanoc::Item.new(
         'blah',
-        { :kind => 'item' },
+        { kind: 'item' },
         '/0/'
       ),
       Nanoc::Item.new(
         'blah',
-        { :kind => 'article', :created_at => (Date.today - 1).to_s }, 
+        { kind: 'article', created_at: (Date.today - 1).to_s },
         '/1/'
       ),
       Nanoc::Item.new(
         'blah',
-        { :kind => 'article', :created_at => (Time.now - 500).to_s },
+        { kind: 'article', created_at: (Time.now - 500).to_s },
         '/2/'
       )
     ]
@@ -88,7 +87,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed
     if_have 'builder' do
       # Create items
-      @items = [ mock, mock_article, mock_article ]
+      @items = [mock, mock_article, mock_article]
 
       # Create item 0
       @items[0].stubs(:[]).with(:kind).returns('item')
@@ -101,15 +100,15 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @items[1].stubs(:[]).with(:custom_path_in_feed).returns(nil)
       @items[1].stubs(:[]).with(:custom_url_in_feed).returns(nil)
       @items[1].stubs(:[]).with(:excerpt).returns(nil)
-      @items[1].stubs(:path).returns("/item1/")
-      @items[1].expects(:compiled_content).with(:snapshot => :pre).returns('item 1 content')
+      @items[1].stubs(:path).returns('/item1/')
+      @items[1].expects(:compiled_content).with(snapshot: :pre).returns('item 1 content')
 
       # Create item 2
-      @items[2].expects(:compiled_content).with(:snapshot => :pre).returns('item 2 content')
+      @items[2].expects(:compiled_content).with(snapshot: :pre).returns('item 2 content')
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -117,7 +116,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
       @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
       @item.stubs(:[]).with(:feed_url).returns(nil)
-      @item.stubs(:path).returns("/journal/feed/")
+      @item.stubs(:path).returns('/journal/feed/')
 
       # Check
       atom_feed
@@ -127,7 +126,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_times
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article, mock_article ]
+      @items = [mock_item, mock_article, mock_article]
 
       # Create item 1
       @items[1].stubs(:[]).with(:updated_at).returns(Time.now - 500)
@@ -141,7 +140,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -149,7 +148,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
       @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
       @item.stubs(:[]).with(:feed_url).returns(nil)
-      @item.stubs(:path).returns("/journal/feed/")
+      @item.stubs(:path).returns('/journal/feed/')
 
       # Check
       atom_feed
@@ -159,11 +158,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_articles
     if_have 'builder' do
       # Mock items
-      @items = [ mock_item, mock_item ]
+      @items = [mock_item, mock_item]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -185,11 +184,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_base_url
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
+      @items = [mock_item, mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({:base_url => nil})
+      @site.stubs(:config).returns({ base_url: nil })
 
       # Create feed item
       @item = mock
@@ -211,11 +210,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_title
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
+      @items = [mock_item, mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -237,11 +236,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_author_name
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
+      @items = [mock_item, mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -263,16 +262,16 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_author_name_and_uri_from_content_item
     if_have 'builder' do
       # Create items
-      @items = [ mock_article ]
+      @items = [mock_article]
 
       # Create item 1
-      @items[0].stubs(:[]).with(:author_name).returns("Don Alias")
-      @items[0].stubs(:[]).with(:author_uri).returns("http://don.example.com/")
+      @items[0].stubs(:[]).with(:author_name).returns('Don Alias')
+      @items[0].stubs(:[]).with(:author_uri).returns('http://don.example.com/')
       @items[0].expects(:compiled_content).returns('item 1 content')
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com/' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com/' })
 
       # Create feed item
       @item = mock
@@ -281,7 +280,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
       @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
       @item.stubs(:[]).with(:feed_url).returns(nil)
-      @item.stubs(:path).returns("/journal/feed/")
+      @item.stubs(:path).returns('/journal/feed/')
 
       # Check
       # TODO: Use xpath matchers for more specific test
@@ -311,11 +310,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_author_uri
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
+      @items = [mock_item, mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -337,13 +336,13 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_without_articles_created_at
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article, mock_article ]
+      @items = [mock_item, mock_article, mock_article]
       @items[1].stubs(:[]).with(:created_at).returns(Time.now.to_s)
       @items[2].stubs(:[]).with(:created_at).returns(nil)
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -365,12 +364,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_title_author_name_and_uri_as_params
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
-      @items[1].expects(:compiled_content).with(:snapshot => :pre).returns('asdf')
+      @items = [mock_item, mock_article]
+      @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -381,9 +380,9 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
       # Check
       atom_feed(
-        :author_name => 'Bob',
-        :author_uri  => 'http://example.com/~bob/',
-        :title       => 'My Blog Or Something'
+        author_name: 'Bob',
+        author_uri: 'http://example.com/~bob/',
+        title: 'My Blog Or Something'
       )
     end
   end
@@ -391,15 +390,15 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_title_author_name_and_uri_from_config
     if_have 'builder' do
       # Create items
-      @items = [ mock_item, mock_article ]
-      @items[1].expects(:compiled_content).with(:snapshot => :pre).returns('asdf')
+      @items = [mock_item, mock_article]
+      @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
       @config = {
-        :author_name => 'Bob',
-        :author_uri  => 'http://example.com/~bob/',
-        :title       => 'My Blog Or Something',
-        :base_url    => 'http://example.com'
+        author_name: 'Bob',
+        author_uri: 'http://example.com/~bob/',
+        title: 'My Blog Or Something',
+        base_url: 'http://example.com'
       }
       @site = mock
       @site.stubs(:config).returns(@config)
@@ -419,15 +418,15 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_articles_param
     if_have 'builder' do
       # Mock items
-      @items = [ mock_article, mock_article ]
+      @items = [mock_article, mock_article]
 
       @items[0].expects(:compiled_content).never
       @items[1].stubs(:[]).with(:title).returns('Item One')
-      @items[1].expects(:compiled_content).with(:snapshot => :pre).returns('asdf')
+      @items[1].expects(:compiled_content).with(snapshot: :pre).returns('asdf')
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -437,14 +436,14 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      atom_feed :articles => [ @items[1] ]
+      atom_feed articles: [@items[1]]
     end
   end
 
   def test_atom_feed_with_limit_param
     if_have 'builder' do
       # Mock articles
-      @items = [ mock_article, mock_article ]
+      @items = [mock_article, mock_article]
       @items.each_with_index do |article, i|
         article.stubs(:[]).with(:title).returns("Article #{i}")
         article.stubs(:[]).with(:created_at).returns(Time.now - i)
@@ -452,7 +451,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -462,7 +461,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      result = atom_feed :limit => 1, :articles => @items
+      result = atom_feed limit: 1, articles: @items
       assert_match(
         Regexp.new('Article 0', Regexp::MULTILINE),
         result
@@ -477,7 +476,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_sorting
     if_have 'builder' do
       # Mock articles
-      @items = [ mock_article, mock_article ]
+      @items = [mock_article, mock_article]
       @items.each_with_index do |article, i|
         article.stubs(:[]).with(:title).returns("Article #{i}")
       end
@@ -486,7 +485,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -504,14 +503,19 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
     end
   end
 
-  def test_atom_feed_with_content_proc_param
+  def test_atom_feed_preserve_order
     if_have 'builder' do
-      # Mock article
-      @items = [ mock_article ]
+      # Mock articles
+      @items = [mock_article, mock_article]
+      @items.each_with_index do |article, i|
+        article.stubs(:[]).with(:title).returns("Article #{i}")
+      end
+      @items[0].stubs(:[]).with(:created_at).returns('01-01-2015')
+      @items[1].stubs(:[]).with(:created_at).returns('01-01-2014')
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -521,7 +525,32 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      result = atom_feed :content_proc => lambda { |a| 'foobar!' }
+      result = atom_feed(preserve_order: true)
+      assert_match(
+        Regexp.new('Article 1.*Article 0', Regexp::MULTILINE),
+        result
+      )
+    end
+  end
+
+  def test_atom_feed_with_content_proc_param
+    if_have 'builder' do
+      # Mock article
+      @items = [mock_article]
+
+      # Mock site
+      @site = mock
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
+
+      # Create feed item
+      @item = mock
+      @item.stubs(:[]).with(:title).returns('My Blog Or Something')
+      @item.stubs(:[]).with(:author_name).returns('J. Doe')
+      @item.stubs(:[]).with(:author_uri).returns('http://example.com/~jdoe')
+      @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
+
+      # Check
+      result = atom_feed content_proc: ->(_a) { 'foobar!' }
       assert_match 'foobar!</content>', result
     end
   end
@@ -529,11 +558,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_excerpt_proc_param
     if_have 'builder' do
       # Mock article
-      @items = [ mock_article ]
+      @items = [mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -543,7 +572,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      result = atom_feed :excerpt_proc => lambda { |a| 'foobar!' }
+      result = atom_feed excerpt_proc: ->(_a) { 'foobar!' }
       assert_match 'foobar!</summary>', result
     end
   end
@@ -551,11 +580,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_icon_param
     if_have 'builder' do
       # Mock article
-      @items = [ mock_article ]
+      @items = [mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -565,7 +594,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      result = atom_feed :icon => 'http://example.com/icon.png'
+      result = atom_feed icon: 'http://example.com/icon.png'
       assert_match '<icon>http://example.com/icon.png</icon>', result
     end
   end
@@ -573,11 +602,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_logo_param
     if_have 'builder' do
       # Mock article
-      @items = [ mock_article ]
+      @items = [mock_article]
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -587,7 +616,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:feed_url).returns('http://example.com/feed')
 
       # Check
-      result = atom_feed :logo => 'http://example.com/logo.png'
+      result = atom_feed logo: 'http://example.com/logo.png'
       assert_match '<logo>http://example.com/logo.png</logo>', result
     end
   end
@@ -595,12 +624,12 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
   def test_atom_feed_with_item_without_path
     if_have 'builder' do
       # Create items
-      @items = [ mock_article ]
+      @items = [mock_article]
       @items[0].stubs(:path).returns(nil)
 
       # Mock site
       @site = mock
-      @site.stubs(:config).returns({ :base_url => 'http://example.com' })
+      @site.stubs(:config).returns({ base_url: 'http://example.com' })
 
       # Create feed item
       @item = mock
@@ -609,7 +638,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
       @item.stubs(:[]).with(:author_name).returns('Denis Defreyne')
       @item.stubs(:[]).with(:author_uri).returns('http://stoneship.org/')
       @item.stubs(:[]).with(:feed_url).returns(nil)
-      @item.stubs(:path).returns("/journal/feed/")
+      @item.stubs(:path).returns('/journal/feed/')
 
       # Check
       atom_feed
@@ -618,7 +647,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_url_for_without_custom_path_in_feed
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
     item = Nanoc::Item.new('content', {}, '/foo/')
@@ -634,11 +663,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_url_for_with_custom_path_in_feed
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
     item = Nanoc::Item.new(
-      'content', { :custom_path_in_feed => '/meow/woof/' }, '/foo/')
+      'content', { custom_path_in_feed: '/meow/woof/' }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
 
     # Check
@@ -650,11 +679,11 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_url_for_with_custom_url_in_feed
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
     item = Nanoc::Item.new(
-      'content', { :custom_url_in_feed => 'http://example.org/x' }, '/foo/')
+      'content', { custom_url_in_feed: 'http://example.org/x' }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
 
     # Check
@@ -676,7 +705,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_url_for_without_path
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
     item = Nanoc::Item.new('content', {}, '/foo/')
@@ -689,7 +718,7 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_feed_url_without_custom_feed_url
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
     @item = Nanoc::Item.new('content', {}, '/foo/')
@@ -705,10 +734,10 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_feed_url_with_custom_feed_url
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create feed item
-    @item = Nanoc::Item.new('content', { :feed_url => 'http://example.com/feed/' }, '/foo/')
+    @item = Nanoc::Item.new('content', { feed_url: 'http://example.com/feed/' }, '/foo/')
     @item.reps << Nanoc::ItemRep.new(@item, :default)
     @item.reps[0].path = '/foo/bar/'
 
@@ -731,10 +760,10 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_atom_tag_for_with_path
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
-    item = Nanoc::Item.new('content', { :created_at => '2008-05-19' }, '/foo/')
+    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
     item.reps[0].path = '/foo/bar/'
 
@@ -744,10 +773,10 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_atom_tag_for_without_path
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
-    item = Nanoc::Item.new('content', { :created_at => '2008-05-19' }, '/baz/qux/')
+    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/baz/qux/')
     item.reps << Nanoc::ItemRep.new(item, :default)
 
     # Check
@@ -756,10 +785,10 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_atom_tag_for_with_base_url_in_dir
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com/somedir' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com/somedir' })
 
     # Create article
-    item = Nanoc::Item.new('content', { :created_at => '2008-05-19' }, '/foo/')
+    item = Nanoc::Item.new('content', { created_at: '2008-05-19' }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
     item.reps[0].path = '/foo/bar/'
 
@@ -769,10 +798,10 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_atom_tag_for_with_time
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
-    item = Nanoc::Item.new('content', { :created_at => Time.parse('2008-05-19') }, '/foo/')
+    item = Nanoc::Item.new('content', { created_at: Time.parse('2008-05-19') }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
     item.reps[0].path = '/foo/bar/'
 
@@ -782,15 +811,14 @@ class Nanoc::Helpers::BloggingTest < Nanoc::TestCase
 
   def test_atom_tag_for_with_date
     # Create site
-    @site = Nanoc::Site.new({ :base_url => 'http://example.com' })
+    @site = Nanoc::Site.new({ base_url: 'http://example.com' })
 
     # Create article
-    item = Nanoc::Item.new('content', { :created_at => Date.parse('2008-05-19') }, '/foo/')
+    item = Nanoc::Item.new('content', { created_at: Date.parse('2008-05-19') }, '/foo/')
     item.reps << Nanoc::ItemRep.new(item, :default)
     item.reps[0].path = '/foo/bar/'
 
     # Check
     assert_equal('tag:example.com,2008-05-19:/foo/bar/', atom_tag_for(item))
   end
-
 end
