@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
-
   include Nanoc::Helpers::Capturing
 
   def test_content_for
@@ -13,9 +12,9 @@ class Nanoc::Helpers::CapturingTest < Nanoc::TestCase
     end
 
     # Build content to be evaluated
-    content = "head <% content_for :sidebar do %>\n" +
-              "  <%= 1+2 %>\n" +
-              "<% end %> foot"
+    content = "head <% content_for :sidebar do %>\n" \
+              "  <%= 1+2 %>\n" \
+              '<% end %> foot'
 
     # Build site
     @site = Nanoc3::Site.new({})
@@ -89,7 +88,7 @@ EOS
 
     @site = Nanoc3::Site.new({})
     @item = Nanoc::Item.new('content', {}, '/')
-    content = "<% content_for :a do %>Content One<% end %>"
+    content = '<% content_for :a do %>Content One<% end %>'
     ::ERB.new(content).result(binding)
 
     assert_equal 'Content One', content_for(@item, :a)
@@ -97,7 +96,7 @@ EOS
 
     @site = Nanoc3::Site.new({})
     @item = Nanoc::Item.new('content', {}, '/')
-    content = "<% content_for :b do %>Content Two<% end %>"
+    content = '<% content_for :b do %>Content Two<% end %>'
     ::ERB.new(content).result(binding)
 
     assert_equal nil,           content_for(@item, :a)
@@ -105,7 +104,7 @@ EOS
   end
 
   def test_dependencies
-    with_site do |site|
+    with_site do |_site|
       # Prepare
       File.open('lib/helpers.rb', 'w') do |io|
         io.write 'include Nanoc::Helpers::Capturing'
@@ -135,7 +134,7 @@ EOS
   end
 
   def test_dependency_without_item_variable
-    with_site do |site|
+    with_site do |_site|
       # Prepare
       File.open('lib/helpers.rb', 'w') do |io|
         io.write "include Nanoc::Helpers::Capturing\n"
@@ -170,14 +169,14 @@ EOS
   end
 
   def test_self
-    with_site do |site|
+    with_site do |_site|
       File.open('lib/helpers.rb', 'w') do |io|
         io.write 'include Nanoc::Helpers::Capturing'
       end
 
       File.open('content/self.erb', 'w') do |io|
-        io.write "<% content_for :foo do %>Foo!<% end %>"
-        io.write "<%= content_for(@item, :foo) %>"
+        io.write '<% content_for :foo do %>Foo!<% end %>'
+        io.write '<%= content_for(@item, :foo) %>'
       end
 
       File.open('Rules', 'w') do |io|
@@ -191,7 +190,7 @@ EOS
   end
 
   def test_recompile_dependency
-    with_site do |site|
+    with_site do |_site|
       # Prepare
       File.open('lib/helpers.rb', 'w') do |io|
         io.write 'include Nanoc::Helpers::Capturing'
@@ -221,5 +220,4 @@ EOS
       assert_equal 'New-Content', File.read('output/includer/index.html')
     end
   end
-
 end
