@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::Helpers::RenderingTest < Nanoc::TestCase
-
   include Nanoc::Helpers::Rendering
 
   def test_render
@@ -38,7 +37,7 @@ class Nanoc::Helpers::RenderingTest < Nanoc::TestCase
         io.write("layout '/foo/', nil\n")
       end
 
-      File.open('layouts/foo.erb', 'w').close()
+      File.open('layouts/foo.erb', 'w').close
 
       assert_raises(Nanoc::Errors::CannotDetermineFilter) do
         render '/foo/'
@@ -54,7 +53,7 @@ class Nanoc::Helpers::RenderingTest < Nanoc::TestCase
         io.write("layout '/foo/', :asdf\n")
       end
 
-      File.open('layouts/foo.erb', 'w').close()
+      File.open('layouts/foo.erb', 'w').close
 
       assert_raises(Nanoc::Errors::UnknownFilter) do
         render '/foo/'
@@ -76,12 +75,11 @@ class Nanoc::Helpers::RenderingTest < Nanoc::TestCase
 
       _erbout = '[erbout-before]'
       result = render '/foo/' do
-        _erbout << "This is some extra content"
+        _erbout << 'This is some extra content'
       end
 
       assert_equal('[erbout-before][partial-before]This is some extra content[partial-after]', _erbout)
       assert_equal '', result
     end
   end
-
 end
