@@ -1,7 +1,6 @@
 # encoding: utf-8
 
 class Nanoc::GemTest < Nanoc::TestCase
-
   def setup
     super
     FileUtils.cd(@orig_wd)
@@ -15,7 +14,7 @@ class Nanoc::GemTest < Nanoc::TestCase
     files_before = Set.new Dir['**/*']
     stdout = StringIO.new
     stderr = StringIO.new
-    piper = Nanoc::Extra::Piper.new(:stdout => stdout, :stderr => stderr)
+    piper = Nanoc::Extra::Piper.new(stdout: stdout, stderr: stderr)
     piper.run(%w( gem build nanoc.gemspec ), nil)
     files_after = Set.new Dir['**/*']
 
@@ -30,5 +29,4 @@ class Nanoc::GemTest < Nanoc::TestCase
   ensure
     Dir['nanoc-*.gem'].each { |f| FileUtils.rm(f) }
   end
-
 end
